C***********************************************************************
C*              ABSORCION QUMICA BINARIA BAJO CONDICIONES             *
C*               ISOTRMICAS,ADIABTICAS Y NO-ISOTRMICAS              *
C***********************************************************************
C*                        DEFINICIN DE VARIABLES                      *
C*    TLA=Temperatura de alimentacin del lquido                      *
C*    TL(I)=Temperatura del lquido en el segmento i                   *
C*    TML=Temperatura del lquido temporal                             *
C*    TGA=Temperatura de alimentacin del gas                          *
C*    TG(I)=Temperatura del gas en el segmento i                       *
C*    TMG=Temperatura del gas temporal                                 *
C*    X1(I)=Fraccin mol de la MEA en el segmento i                    *
C*    W1(I)=Fraccin peso de la MEA en el segmento i                   *
C*    X1A=Fraccin mol de la MEA en la alimentacin                    *
C*    W1A=Fraccin peso de la MEA en la alimentacin                   *
C*    X1M=Fraccin mol de la MEA temporal                              *
C*    XI(J,I)=Fraccin mol total en el lquido (antes de la reaccin)  *
C*            del compuesto J en el segmento i                         *
C*    XIM(J)=Fraccin mol total en el lquido temporal y antes de la   *
C*           reaccin del compuesto j                                  *
C*    Y2(I)=Mol del CO2/Mol de MEA en el lquido en el segmento i      *
C*    Y2M=Mol del CO2/ Mol de MEA temporal                             *
C*    Y2A=Mol de CO2/Mol de MEA en la alimentacin lquida             *
C*    YA(J)=Fraccin mol del compuesto j en el gas de alimentacin     *
C*    YAIR=Fraccin mol del aire en la alimentacin gaseosa            *
C*    YM(J)=Fraccin mol en el gas del compuesto j temporal            *
C*    Y(J,I)=Fraccin mol en el gas del compuesto j en el segmento i   *
C*    LR=Lectura del rotmetro >1                                      *
C*    P1=Presin en el manmetro 1                                     *
C*    DP=Cada de presin en la placa de orificio                      *
C*    Z=Altura del segmento i                                          *
C*    TA=Temperatura ambiente                                          *
C*    ZT=Altura total del empaque                                      *
C*    CPML=Capacidad calorfica del lquido temporal                   *
C*    DML=Densidad del lquido temporal                                *
C*    CTML=Conductividad trmica del lquido temporal                  *
C*    VML=Viscosidad del lquido temporal                              *
C*    TSM=Tensin superficial temporal                                 *
C*    DFML(J)=Difusividad del compuesto j en el lquido temporal       *
C*    CPL(I)=Capacidad calorfica del lquido en el segmento i         *
C*    DL(I)=Densidad del lquido en el segmento i                      *
C*    CTL(I)=Conductividad trmica del lquido en el segmento i        *
C*    VL(I)=Viscosidad del lquido en el segmento i                    *
C*    TS(I)=Tensin superficial en el segmento i                       *
C*    DFL(J,I)=Difusividad del compuesto j en el lquido en el         *
C*             segmento i                                              *
C*    FL1A=Flujo del lquido en Kg/s en la alimentacin                *
C*    FL2A=Flujo del lquido en Kg/ms en la alimentacin              *
C*    FL3A=Flujo del lquido en Kmol/ms en la alimentacin            *
C*    FL2(I)=Flujo del lquido en Kg/ms en el segmento i              *
C*    FL3(I)=Flujo del lquido en Kmol/ms en el segmento i            *
C*    FL2M=Flujo del lquido en Kg/ms temporal                        *
C*    FL3M=Flujo del lquido en Kmol/ms temporal                      *
C*    RT(I)=Retencin total del lquido en el segmento i               *
C*    RTM=Retencin total del lquido temporal                         *
C*    Q(I)=Transferencia de calor con los alrededores en el segmento i *
C*    QM=Transferencia de calor con los alrededores temporal           *
C*    FG1A=Flujo del gas en Kg/s en la alimentacin                    *
C*    FG2A=Flujo del gas en Kg/ms en la alimentacin                  *
C*    FG3A=Flujo del gas en Kmol/ms en la alimentacin                *
C*    FL2(I)=Flujo del gas en Kg/ms en el segmento i                  *
C*    FL3(I)=Flujo del gas en Kmol/ms en el segmento i                *
C*    FG2M=Flujo del gas en Kg/ms temporal                            *
C*    FG3M=Flujo del gas en Kmol/ms temporal                          *
C*    CPMG=Capacidad calorfica del gas temporal                       *
C*    DMG=Densidad del gas temporal                                    *
C*    CTMG=Conductividad trmica del gas temporal                      *
C*    VMG=Viscosidad del gas (temporal) en el segmento i               *
C*    DFMG(J)=Difusividad del compuesto J temporal en el gas           *
C*    AM=Area interfacial temporal                                     *
C*    CP=Cada de presin en el lecho empacado                         *
C*    PIN=Porciento de inundacin                                      *
C*    CTCMG=Coeficiente de transferencia de calor del gas              *
C*    CTCG(I)=Coeficiente de transferencia de calor del gas en el      *
C*            segmento i                                               *
C*    CTCML=Coeficiente de transferencia de calor del lquido temporal *
C*    CTCL(I)=Coeficiente de transferencia de calor del lquido en el  *
C*            segmento i                                               *
C*    HTUMG(J)=Altura de una unidad de transferencia del gas del       *
C*             compuesto j temporal                                    *
C*    HTUG(I)=Altura de una unidad de transferencia del gas del CO2    *
C*            en el segmento i                                         *
C*    HTUML(J)=Altura de una unidad de transferencia del lquido del   *
C*             compuesto j temporal                                    *
C*    HTUL(I)=Altura de una unidad de trasnferencia del lquido del CO2*
C*            en el segmento i                                         *
C*    CTLBM=Molaridad total temporal en el bulto del lquido en el     *
C*    CEM(J)=Molaridad del compuesto j temporal en el bulto del lquido*
C*    HRTM=Calor de reaccin temporal                                  *
C*    HRT(I)=Calor de reaccin hasta el segmento i                     *
C*    CTLIA=Molaridad total antes de la reaccin en la alimentacin    *
C*    CTLIM=Molaridad total temporal antes de la reaccin              *
C*    CTLI(I)=Molaridad total antes de la reaccin en el segmentio i   *
C*    N1=Flux molar interfacial del CO2 temporal                       *
C*    N(I)=Flux molar interfacial del CO2 en el segmento i             *
C*    YC(I)=Concentracin en el gas del CO2 en el segmento i que se    *
C*          compara con Y(1,I) como criterio de convergencia           *
C*    NM(J)=Flyx interfacial temporal del compuesto J                  *
C*    EM=Factor de aceleracin al coeficiente de transferencia de      *
C*       masa temporal                                                 *
C*    E(I)=Factor de aceleracin al coeficnete de transferencia de     *
C*         masa en el segmento i                                       *
C*    YIN(I)=Fraccin mol interfacial en el gas del CO2 en el          *
C*           segmento i                                                *
C*    YINM=Fraccin mol interfacial temporal en el gas del CO2         *
C*    XIN(I)=Fraccin mol interfacil en el lquido del CO2 en el       *
C*           segmento i                                                *
C*    XINM=Fraccin mol interfacil temporal en el lquido del CO2      *
C*    YBM=Fraccin mol temporal en el bulto del gas del CO2            *
C*    YB(I)=Fraccin mol en el bulto del gas del CO2 en el segmento i  *
C*    XB(J,I)=Fraccin mol en el bulto del lquido del compuesto j     *
C*            en el segmento i                                         *
C*    XBM(J)=Fraccin mol temporal en el bulto del lquido del         *
C*           compuesto j                                               *
C*    YS(J)=Fraccin mol total en el gas del compuesto j en el         *
C*          siguiente segemento                                        *
C*    FGS=Flujo del gas en Kmol/ms en el siguiente segmento           *
C*    FLS=Flujo del lquido en Kmol/ms en el siguiente segmento       *
C*    XS(J)=Fraccin mol total del lquido sin reaccin qumica        *
C*          en el siguiente segmento                                   *
C*    TGS=Temperatura del gas en el siguiente segmento                 *
C*    QI(I)=Fujo interfacial de calor en el segmento i                 *
C*    QIM=Flujo interfacial temporal de calor                          *
C*    PMG=Peso molecular temporal del gas                              *
C*    HRTI=Calor de reaccin del segmento i                            *
C*    TLS=Temperatura del lquido del segmento siguiente               *
C*    PML=Peso molecular temporal del lquido                          *
C*    SUM=Suma de los flux interfaciales de cada segmento a todo lo    *
C*        largo del lecho empacado                                     *
C*    A(I)=Area interfacial en el segmento i                           *
C*    TFM=Coeficiente temporal de Ackermann                            *
C*    TF(I)=Coeficiente de Ackermann en el segmento i                  *
C*    TI(I)=Temperatura interfacil en el segmento i                    *
C*    TIM=Temperatura temporal interfacial                             *
C*    P2=Presin absoluta en cada segemento                            *
C*    YG(I)=Fraccin mol del CO2 en el gas en las grficas             *
C*    XG(I)=Fraccin mol del CO2 en el lquido en las grficas         *
C*    HRTA=Calor de reaccin en la alimentacin                        *
C*    CTLB(I)=Molaridad total en el bulto del lquido en el segmento i *
C*    C1=Coeficiente de correccin al flux del CO2 interfacial         *
C*    C2=Exponente de correccin al flux del CO2 interfacial           *
C***********************************************************************
      DOUBLE PRECISION TLA,TL(51),TML,TGA,TG(51),TMG,X1(51),W1(51),X1A,W
     $1A,X1M,W1M,XI(3,51),XIM(3),Y2(51),Y2M,Y2A,YA(5),YAIR,YM(5),Y(5,51)
     $,LR,P1,DP,Z,TA,ZT,CPML,DML,CTML,VML,TSM,DFML(3),CPL(51),DL(51),CTL
     $(51),VL(51),TS(51),DFL(3,51),FL1A,FL2A,FL3A,FL2(51),FL3(51),FL2M,F
     $L3M,RT(51),RTM,Q(51),QM,FG1A,FG2A,FG3A,FG2(51),FG3(51),FG2M,FG3M,C
     $PMG,DMG,CTMG,VMG,DFMG(3),AM,CP,PIN,CTCMG,CTCG(51),CTCML,CTCL(51),H
     $TUMG(2),HTUG(51),HTUML(2),HTUL(51),CTLBM,CEM(8),HRTM,HRT(51),CTLIA
     $,CTLIM,CTLI(51),N(2,51),YC(51),NM(2),EM,E(51),YIN(51),YINM,XIN(51)
     $,XINM,YBM(2),XBM(3),YB(2,51),XB(3,51),YS(3),FGS,FLS,XS(3),TGS,QI(5
     $1),QIM,PMG,HRTI,TLS,PML,SUM,A(51),TFM,TF(51),TI(51),TIM,P2,YG(51),
     $XG(51),HRTA,CTLB(51),SUM1,HA(51),HAM
      INTEGER S1,S2,SC,SM,IR,NS,GRF,IN
      CHARACTER COMP(2)*3,FECHA*8,COMND*10,CLAVE*16
      DATA COMP/'CO2','H2O'/
C***********************************************************************
C*                       PRESENTACIN DEL PROGRAMA                     *
C***********************************************************************
      COMND='CLS'
      CALL SYSTEM (COMND)
 0010 WRITE(*,20)
 0020 FORMAT(1X,'Para hacer uso de este programa usted necesita una cla
     $ve de acceso!',/,1X,' Clave de acceso ? ')
      READ(*,FMT='(A16)',ERR=10)CLAVE
      IF (CLAVE.NE.'UNAM_IQ') THEN
      STOP
      END IF
      CALL SYSTEM (COMND)
 0030 WRITE(*,40)
 0040 FORMAT(11(/),T19,'ABSORCION DE CO2 EN SOLUCIONES ACUOSAS DE MEA',1
     $2(/),T72,'UNAM-IQ',/)
      COMND='PAUSE'
      CALL SYSTEM (COMND)
      COMND='CLS'
      CALL SYSTEM (COMND)
      WRITE(*,50)
 0050 FORMAT(T34,'TORRE EMPACADA',/,T40,'')
      WRITE(*,60)
 0060 FORMAT(T35,'ͼ ͻ',/,T31,'͹         ',/,T31,'',T35,'
     $',/,T31,'',T35,'',/,T31,'',T35,''
     $,/,T31,'',T35,'',/,T20,'Vlvula 1',T31,'',T35,'
     $',T69,' ',T74,'Aire',/,T31,'',T35,'',T59,'Vlv
     $ula 2',T69,'',/,T31,'',T35,'',T69,'',/,T31,'',T35,'
     $',T69,'',/,T20,'Rotmetro',T31,'',T35,'',T
     $57,'Manmetro 1',T69,'',/,T31,'',T35,'',T69,'   ',/
     $,T4,'Tanque de',T31,'',T35,'',T57,'Manmetro 2',T69,'
     $ͻ',/,T2,'almacenamiento',T30,'',T35,'',T60,'
     $',T69,'',T72,'ͻ',/,T3,'ͻ',T31,'',T35,'
     $',T60,'   ',T69,'',T72,'     ',/,T3,' Solucin ',T31,''
     $,T35,'.........ʳ|ͼ',T72,' CO2 ',/,T3,'
     $acuosa  ',T31,'',T35,'......... Vlvula 4   Placa de',T72,'
     $   ',/,T3,'  de MEA  ',T31,'',T35,'',T59,'orificio'
     $,T72,'     ',/,T3,'ͼ',T20,'Bomba',T31,'',T35,'
     $ͼ',T72,'ͼ',/,T9,'͝ͼ',T40,'ͻ 
     $',/,T46,' Lquido enriquecido',/)
      COMND='PAUSE'
      CALL SYSTEM (COMND)
C***********************************************************************
C*                            ENTRADA DE DATOS                         *
C***********************************************************************
 0070 COMND='CLS'
      CALL SYSTEM (COMND)
      WRITE(*,80)
 0080 FORMAT(T32,'DATOS DE ENTRADA',/)
 0090 WRITE(*,*)'Operacin Isotrmica[1], Adiabtica[2]  No-isotrmica[
     $3] ? '
      READ(*,*,ERR=90)M
      IF (M.LT.1.OR.M.GT.3) GOTO 90
 0100 WRITE(*,110)
 0110 FORMAT(/,T34,'TEMPERATURAS')
      GOTO (120,150,140) M
 0120 WRITE(*,130)
 0130 FORMAT(1X,'Temperatura del sistema [K] = ? ')
      READ(*,*,ERR=120)TLA
      TGA=TLA
      TA=TLA
      IF (TLA.LE.273.15) GOTO 120
      GOTO 170
 0140 WRITE(*,*)'Temperatura ambiente [K] = ? '
      READ(*,*,ERR=140)TA
      IF (TA.LE.0)  GOTO 140
 0150 WRITE(*,*)'Temperatura del lquido de alimentacin [K] = ? '
      READ(*,*,ERR=150)TLA
      IF (TLA.LE.273.15) GOTO 150
 0160 WRITE(*,*)'Temperatura del gas de alimentacin [K] = ? '
      READ(*,*,ERR=160)TGA
      IF (TGA.LE.0) GOTO 160
 0170 WRITE(*,180)
 0180 FORMAT(/,T21,'CONCENTRACIONES Y FLUJO EN EL LIQUIDO')
 0190 WRITE(*,*)'Fraccin peso de la MEA sin CO2 = ? '
      READ(*,*,ERR=190)W1A
      IF (W1A.LT.0.OR.W1A.GT.1) GOTO 190
 0200 WRITE(*,*)'Mol de CO2/Mol de MEA en la alimentacin = ? '
      READ(*,*,ERR=200)Y2A
      IF (Y2A.LT.0) GOTO 200
 0210 WRITE(*,*)'Lectura del rotmetro = ? '
      READ(*,*,ERR=210)LR
      IF (LR.LT.1) GOTO 210
      WRITE(*,220)
 0220 FORMAT(/,T23,'CONCENTRACIONES Y FLUJO EN EL GAS')
      DO I=1,2
 0230 WRITE(*,240)COMP(I)
 0240 FORMAT(1X,'Frac. mol del ',A3,' en el gas de alimentacin = ? ')
      READ(*,*,ERR=230)YA(I)
      IF (YA(I).LT.0.OR.YA(I).GT.1) GOTO 230
      END DO
 0250 WRITE(*,*)'Presin manomtrica de alimentacin [Kg/cm] = ? '
      READ(*,*,ERR=250)P1
      IF (P1.LE.0) GOTO 250
 0260 WRITE(*,*)'Cada de presin en la placa de orificio [cm H2O] = ? '
      READ(*,*,ERR=260)DP
      IF (DP.LE.0) GOTO 260
      WRITE(*,270)
 0270 FORMAT(/,T25,'CARACTERSTICAS DEL EMPAQUE')
 0280 WRITE(*,*)'Altura del lecho empacado [m] = ? '
      READ(*,*,ERR=280)ZT
      IF (ZT.LE.0) GOTO 280
      WRITE(*,290)
 0290 FORMAT(/)
 0340 COMND='PAUSE'
      CALL SYSTEM (COMND)
C***********************************************************************
C*      CALCULO DE LAS VARIABLES EN LAS CORRIENTES DE ALIMENTACION:    *
C*      CADA DE PRESION EN LA COLUMNA, % DE INUNDACIN,ALTURA DE      *
C*      CADA SEGMENO,PRESION ABSOLUTA,A LA ENTRADA,CONCENTRACIONES     *
C*      Y PROPIEDADES FISICO QUIMICA.                                  *
C***********************************************************************
 0350 NS=51
      Z=ZT/NS
      IN=(NS-1)/10
      P1=P1*1.01325D0/1.0333D0+0.78D0
      YAIR=1-YA(1)-YA(2)
      YA(3)=0.7806D0*YAIR
      YA(4)=0.2101D0*YAIR
      YA(5)=0.0093D0*YAIR
      CALL CPGAS (TGA,YA,CPMG)
      CALL VISGAS (TGA,P1,YA,VMG)
      CALL DENGAS (TGA,P1,YA,DMG,PMG)
      CALL FLUGAS (YA,P1,DP,DMG,CPMG,VMG,FG1A,FG2A,FG3A)
      TG(1)=TGA
      DO I=1,5
      Y(I,1)=YA(I)
      END DO
      YB(1,1)=YA(1)
      YB(2,1)=YA(2)
      FG2(1)=FG2A
      FG3(1)=FG3A
      X1A=W1A*18.015D0/((1-W1A)*61.084D0+W1A*18.015D0)
      CALL DENLIQ (TLA,X1A,DML)
      CALL FLULIQ (W1A,X1A,LR,DML,FL1A,FL2A,FL3A)
      CALL CAIPRE (DMG,DML,FG1A,FL1A,CP,PIN,*360,*70)
 0360 COMND='CLS'
      CALL TIMER (S1)
      CALL SYSTEM (COMND)
      WRITE(*,370)
 0370 FORMAT(12(/),T31,'REALIZANDO CALCULOS',12(/))
      CTLIA=DML*(W1A*(1+Y2A)/61.084D0+(1-W1A)/18.015D0)
      IF (Y2A.GT.0) THEN
      CALL EQUQUI (TLA,W1A,Y2A,DML,CEM,CTLBM)
      CALL CALSOL (TLA,CEM,CTLBM,HRTM)
      HRTA=HRTM
      ELSE
      HRTA=0
      END IF
C***********************************************************************
C*    ASIGNACIN DE LAS VARIABLES DE LA ALIMENTACIN LIQUIDA A CADA    *
C*    UNO DE LOS SEGMENTOS EN LOS QUE SE DIVIDIO EL LECHO EMPACADO     *
C***********************************************************************
      DO I=1,NS
      TL(I)=TLA
      X1(I)=X1A
      W1(I)=W1A
      Y2(I)=Y2A
      XI(2,I)=(1-X1A)/(1+Y2A*X1A)
      XI(3,I)=X1A/(1+Y2A*X1A)
      XI(1,I)=1-XI(2,I)-XI(3,I)
      FL2(I)=FL2A
      FL3(I)=FL3A
      CTLI(I)=CTLIA
      END DO
C***********************************************************************
C*         SUMATORIA DE LAS CONCENTRACIONES PARA CRITERIO DE PARO      *
C***********************************************************************
      SUM1=0
      DO I=1,NS
      YC(I)=YA(1)
      SUM1=SUM1+YC(I)
      END DO
C***********************************************************************
C*    CALCULO DE LAS PROPIEDADES FISICO-QUMICAS DEL LQUIDO PARA      *
C*      CADA UNO DE LOS SEGMENTOS A LO LARGO DE TODA LA COLUMNA        *
C***********************************************************************
 0380 DO I=1,NS
      TML=TL(I)
      W1M=W1(I)
      X1M=X1(I)
      Y2M=Y2(I)
      FL2M=FL2(I)
      CALL DENLIQ (TML,X1M,DML)
      CALL VISLIQ (TML,X1M,VML)
      CALL TENSUP (TML,X1M,TSM)
      CALL CTLIQ (TML,W1M,CTML)
      CALL CPLIQ (TML,X1M,CPML)
      CALL DIFLIQ (TML,W1M,X1M,VML,DML,DFML)
      CALL RETLIQ (DML,TSM,VML,FL2M,RTM)
      IF (Y2M.GT.0) THEN
      CALL EQUQUI (TML,W1M,Y2M,DML,CEM,CTLBM)
      CTLB(I)=CTLBM
      IF (M.NE.1)  THEN
      CALL CALSOL (TML,CEM,CTLBM,HRTM)
      HRT(I)=HRTM
      ELSE
      HRT(I)=0
      END IF
      XB(1,I)=CEM(2)/CTLBM
      XB(2,I)=CEM(1)/CTLBM
      XB(3,I)=CEM(5)/CTLBM
      ELSE
      HRT(I)=0
      CTLB(I)=CTLIA
      XB(1,I)=0
      XB(2,I)=XI(3,I)
      XB(3,I)=XI(2,I)
      END IF
      DL(I)=DML
      VL(I)=VML
      TS(I)=TSM
      CTL(I)=CTML
      CPL(I)=CPML
      DFL(1,I)=DFML(1)
      DFL(2,I)=DFML(2)
      DFL(3,I)=DFML(3)
      RT(I)=RTM
      IF (M.EQ.3.AND.TA.NE.TL(I)) THEN
      CALL FLUCAL (TA,TML,QM)
      Q(I)=QM
      ELSE
      Q(I)=0
      END IF
      END DO
C***********************************************************************
C*    CACULO DE LAS PROPIEDADES FISICO-QUMICAS DE LA FASE GASEOSA     *
C*     EN CADA UNO DE LOS SEGMENTOS A LO LARGO DE TODA LA COLUMNA      *
C***********************************************************************
      P2=P1+DP*1.01325D0/14.696D0
      DO I=1,NS
      TMG=TG(I)
      TML=TL(I)
      DO J=1,5
      YM(J)=Y(J,I)
      END DO
      DO J=1,3
      DFML(J)=DFL(J,I)
      END DO
      FG2M=FG2(I)
      FG3M=FG3(I)
      FL2M=FL2(I)
      FL3M=FL3(I)
      CTLIM=CTLI(I)
      CTLBM=CTLB(I)
      YBM(1)=YB(1,I)
      YBM(2)=YB(2,I)
      XBM(1)=XB(1,I)
      XBM(2)=XB(2,I)
      XBM(3)=XB(3,I)
      DML=DL(I)
      TSM=TS(I)
      VML=VL(I)
      RTM=RT(I)
      CPML=CPL(I)
      CTML=CTL(I)
      X1M=X1(I)
      CALL CPGAS (TMG,YM,CPMG)
      CALL CTGAS (TMG,YM,CTMG)
      CALL VISGAS (TMG,P2,YM,VMG)
      CALL DIFGAS (TMG,P2,YM,DFMG)
      CALL DENGAS (TMG,P2,YM,DMG,PMG)
      CALL AREA(FL2M,FG2M,DML,TSM,VML,DMG,AM)
      CALL CTCGAS (CPMG,VMG,CTMG,RTM,YM,FG2M,CTCMG)
      CALL CTCLIQ (CPML,VML,CTML,X1M,FL2M,CTCML)
      CALL HTUGAS (TML,FL2M,ZT,VML,DML,TSM,DMG,VMG,DFMG,PIN,HTUMG)
      CALL HTULIQ (VML,DML,DFML,PIN,FL2M,ZT,HTUML)
      CALL CONIN2 (TML,P2,FL3M,FG3M,HTUML,HTUMG,YBM,XBM,DFML,AM,CTLIM,CT
     $LBM,NM,EM,YINM,XINM,HAM)
      CALL FGSMOL (YM,NM,FG3M,Z,FGS,YS)
      IF (TMG.NE.TML) THEN
      CALL TEMGAI (TMG,TML,YM,YS,FG3M,FGS,AM,Z,CTCMG,CTCML,NM,TFM,TIM,TG
     $S,QIM)
      TI(I)=TIM
      TF(I)=TFM
      QI(I)=QIM
      ELSE
      TI(I)=TML
      TF(I)=1
      QI(I)=0
      TGS=TML
      END IF
      HTUG(I)=HTUMG(1)
      HTUL(I)=HTUML(1)
      CTCG(I)=CTCMG
      CTCL(I)=CTCML
      N(1,I)=NM(1)
      N(2,I)=NM(2)
      HA(I)=HAM
      E(I)=EM
      YIN(I)=YINM
      XIN(I)=XINM
      A(I)=AM
      IF (I.LT.NS) THEN
      Y(1,I+1)=YS(1)
      Y(2,I+1)=YS(2)
      Y(3,I+1)=YS(3)*0.7806D0
      Y(4,I+1)=YS(3)*0.2101D0
      Y(5,I+1)=YS(3)*0.0093D0
      YB(1,I+1)=YS(1)
      YB(2,I+1)=YS(2)
      FG2(I+1)=FGS*PMG
      FG3(I+1)=FGS
      TG(I+1)=TGS
      P2=P2-CP*Z*101.325D0/(30.48D0*406.8D0)
      END IF
      END DO
C***********************************************************************
C*     CALCULO DE LAS NUEVAS CONCENTRACIONES Y FLUJOS EN LA FASE       *
C*              LIQUIDA A LO LARGO DE TODA LA COLUMNA                  *
C***********************************************************************
      DO I=NS,2,-1
      NM(1)=N(1,I)
      NM(2)=N(2,I)
      FL3M=FL3(I)
      XIM(1)=XI(1,I)
      XIM(2)=XI(2,I)
      XIM(3)=XI(3,I)
      CALL FLSMOL (XIM,NM,FL3M,Z,FLS,XS)
      TML=TL(I)
      CPML=CPL(I)
      AM=A(I)
      QM=Q(I)
      QIM=QI(I)
      IF (I.EQ.NS) THEN
      HRTI=HRT(I)-HRTA
      ELSE
      HRTI=HRT(I)-HRT(I+1)
      ENDIF
      IF (M.NE.1) THEN
      CALL TEMLIQ (TML,CPML,FL3M,FLS,QM,QIM,Z,AM,HRTI,TLS)
      ELSE
      TLS=TML
      END IF
      TL(I-1)=TLS
      Y2(I-1)=XS(1)/XS(3)
      X1(I-1)=1/(1+XS(2)/XS(3))
      W1(I-1)=1/(1+18.015D0*XS(2)/(61.084D0*XS(3)))
      PML=44.01D0*XS(1)+18.015D0*XS(2)+61.084D0*XS(3)
      XI(1,I-1)=XS(1)
      XI(2,I-1)=XS(2)
      XI(3,I-1)=XS(3)
      FL2(I-1)=FLS*PML
      FL3(I-1)=FLS
      END DO
C***********************************************************************
C*    VERIFICACION DE LA CONVERGENCIA DE LOS FLUX INTERFACIALES DEL    *
C*                                    CO2                              *
C***********************************************************************
      SUM=0
      DO I=1,NS
      SUM=SUM+Y(1,I)
      END DO
      IF (ABS(SUM-SUM1)/SUM1.LT.1D-2) THEN
      CALL SYSTEM (COMND)
      DP=DP*406.8D0*2.54D0/14.696D0
      P1=(P1-0.78D0)*1.0333D0/1.01325D0
      WRITE(*,390)
 0390 FORMAT(13(/),T32,'CALCULOS FINALIZADOS',10(/))
      CALL TIMER (S2)
      S3=REAL(S2-S1)
      S4=S3/100
      WRITE(*,400)S4
 0400 FORMAT(/,1X,'Tiempo de corrida ',F15.2,' segundos',/)
      COMND='PAUSE'
      CALL SYSTEM (COMND)
      COMND='CLS'
      IR=2
      OPEN(9,FILE='PRN')
C***********************************************************************
C*                        IMPRESION DE RESULTADOS                      *
C***********************************************************************
 0410 IF (IR.EQ.1) THEN
      CALL SYSTEM (COMND)
      WRITE(*,420)
 0420 FORMAT(12(/),T30,'IMPRIMIENDO RESULTADOS',12(/))
      WRITE(9,430)
 0430 FORMAT('1',/,T18,'ABSORCION DE CO2 EN UNA MEZCLA ACUAOSA DE MEA ',
     $/,T28,'EN UNA TORRE EMPACADA',/)
      CALL DATE(FECHA)
      WRITE(9,440)FECHA
 0440 FORMAT(1X,'Fecha ',A8,/)
      WRITE(9,450)PIN,CP,TA,W1A,LR,DP,P1,ZT
 0450 FORMAT(1X,'Porciento de inundacin                    ',G15.4,/,
     $       1X,'Cada de presin [inH2O/ft]                ',G15.4,/,
     $       1X,'Temperatura del ambiente [K]              ',G15.5,/,
     $       1X,'Fraccin peso de la MEA en la alimentacin ',G15.4,/,
     $       1X,'Lectura del rotmetro                      ',G15.3,/,
     $       1X,'Cada de presin en la P.O. [cmH2O]        ',G15.3,/,
     $       1X,'Presin en el manmetro 1 [Kg/cm]         ',G15.3,/,
     $       1X,'Altura del empaque [m]                     ',G15.3)
      WRITE(9,460)
 0460 FORMAT(/,1X,'Altura del empaque',T25,'Temperatura',T42,'Temperatur
     $a',T60,'Temperatura',/,T6,'(Fraccin)',T25,'del gas [K]',T40,'del
     $ lquido [K]',T58,'interfacial [K]')
      DO I=1,NS,IN
      FA=REAL(I)/REAL(NS)
      WRITE(9,470)FA,TG(I),TL(I),TI(I)
 0470 FORMAT(T7,F6.1,T22,G15.4,T39,G15.4,T57,G15.4)
      END DO
      WRITE(9,480)
 0480 FORMAT(/,T25,'Fraccin mol',T42,'Fraccin mol',T60,'Fraccin mol',
     $/,T25,'del CO2 (Gas)',T42,'del H2O (Gas)',T58,'bulto del lq. CO2'
     $)
      DO I=1,NS,IN
      FA=REAL(I)/REAL(NS)
      WRITE(9,490)FA,Y(1,I),Y(2,I),XB(1,I)
 0490 FORMAT(T7,F6.1,T21,G15.4,T38,G15.4,T58,G15.4)
      END DO
      WRITE(9,500)
 0500 FORMAT(/,T25,'Fraccin mol',T42,'Fraccin mol',T60,'Fraccin mol',
     $/,T23,'total CO2 (lq.)',T40,'total H2O (lq.)',T58,'bulto del lq
     $. MEA')
      DO I=1,NS,IN
      FA=REAL(I)/REAL(NS)
      WRITE(9,510)FA,(XI(J,I),J=1,2),XB(2,I)
 0510 FORMAT(T7,F6.1,T21,G15.4,T40,G15.4,T56,G15.4)
      END DO
      WRITE(9,520)
 0520 FORMAT('1',//,1X,'Altura del empaque',T25,'Flux del CO2',T42,'Frac
     $cin mol',T60,'Fraccin mol',/,T6,'(Fraccin)',T26,'[Kmol/ms]',T4
     $1,'CO2 (int. gas)',T59,'CO2 (int. lq.)')
      DO I=1,NS,IN
      FA=REAL(I)/REAL(NS)
      WRITE(9,530)FA,N(1,I),YIN(I),XIN(I)
 0530 FORMAT(T7,F6.1,T21,G15.4,T39,G15.4,T56,G15.4)
      END DO
      WRITE(9,540)
 0540 FORMAT(/,T24,'Flujo del lq.',T41,'Flujo del gas',T64,'HTUl',/,T26
     $,'[Kmol/ms]',T42,'[Kmol/ms]',T64,'[m]')
      DO I=1,NS,IN
      FA=REAL(I)/REAL(NS)
      WRITE(9,550)FA,FL3(I),FG3(I),HTUL(I)
 0550 FORMAT(T7,F6.1,T21,G15.5,T38,G15.5,T57,G15.4)
      END DO
      WRITE(9,560)
 0560 FORMAT(/,T29,'CTCl',T45,'CTCg',T64,'HTUg',/,T27,'[W/mK]',T43,'[W
     $/mK]',T64,'[m]')
      DO I=1,NS,IN
      FA=REAL(I)/REAL(NS)
      WRITE(9,570)FA,CTCL(I),CTCG(I),HTUG(I)
 0570 FORMAT(T7,F6.1,T23,G15.5,T38,G15.3,T57,G15.4)
      END DO
      WRITE(9,580)
 0580 FORMAT(/,T24,'Flux de calor',T41,'Flux de calor',T60,'Flux del H2O
     $',/,T23,'alred. [W/ms]',T40,'interf. [W/ms]',T61,'[kmol/ms]')
      DO I=1,NS,IN
      FA=REAL(I)/REAL(NS)
      WRITE(9,590)FA,Q(I),QI(I),N(2,I)
 0590 FORMAT(T7,F6.1,T21,G15.4,T38,G15.4,T56,G15.4)
      END DO
      WRITE(9,600)
 0600 FORMAT('1',/,1X,'Altura del empaque',T26,'Factor de',T43,'Factor d
     $e',T61,'Nmero de',/,T6,'(Fraccin)',T26,'Ackermann',T42,'acelerac
     $in',T63,'Hatta')
      DO I=1,NS,IN
      FA=REAL(I)/REAL(NS)
      WRITE(9,610)FA,TF(I),E(I),HA(I)
 0610 FORMAT(T7,F6.1,T22,G15.4,T39,G15.4,T57,G15.4)
      END DO
      WRITE(9,620)S4
 0620 FORMAT(/,1X,'Tiempo de corrida ',F15.2,' segundos ')
      END IF
      IF (IR.NE.1) THEN
      IF (M.NE.1) THEN
      CALL SYSTEM (COMND)
      WRITE(*,630)
 0630 FORMAT(15X,'Temperatura del lquido [K] vs Frccin altura del emp
     $aque')
      GRF=1
      CALL GRAFICA (NS,TL,GRF)
      CALL SYSTEM (COMND)
      WRITE(*,650)
 0650 FORMAT(17X,'Temperatura del gas [K] vs Fraccin altura del empaqu
     $e')
      CALL GRAFICA (NS,TG,GRF)
      END IF
      CALL SYSTEM (COMND)
      WRITE(*,670)
 0670 FORMAT(17X,'Flujo del gas [Kmol/ms] vs Fraccin altura del empaqu
     $e')
      GRF=2
      CALL GRAFICA (NS,FG3,GRF)
      CALL SYSTEM (COMND)
      WRITE(*,690)
 0690 FORMAT(16X,'Flujo del lquido [Kmol/ms] vs Fraccin altura del em
     $paque')
      CALL GRAFICA (NS,FL3,GRF)
      DO I=1,NS
      YG(I)=Y(1,I)
      END DO
      CALL SYSTEM (COMND)
      WRITE(*,710)
 0710 FORMAT(14X,'Fraccin mol del CO2 en el gas vs Fraccin altura del
     $empaque')
      GRF=3
      CALL GRAFICA (NS,YG,GRF)
      DO I=1,NS
      XG(I)=XI(1,I)
      END DO
      CALL SYSTEM (COMND)
      WRITE (*,730)
 0730 FORMAT(12X,'Fraccin mol del CO2 en el lquido vs Fraccin altura
     $del empaque')
      CALL GRAFICA (NS,XG,GRF)
      COMND='CLS'
      CALL SYSTEM (COMND)
 0750 WRITE(*,760)
 0760 FORMAT(1X,' Imprimir resultados s[1]  no [2] ? ')
      READ(*,*,ERR=750)IR
      IF (IR.NE.1.AND.IR.NE.2) GOTO 750
      IF (IR.EQ.1) GOTO 410
      END IF
      CALL SYSTEM (COMND)
 0770 WRITE(*,780)
 0780 FORMAT(/,1X,' Cambiar alguna expecificacin s[1]  no[2] ? ')
      READ(*,*,ERR=770)SC
      IF (SC.NE.1.AND.SC.NE.2) GOTO 770
 0790 CALL SYSTEM (COMND)
      IF (SC.NE.1) THEN
 0800 WRITE(*,810)
 0810 FORMAT(12(/),T35,'FIN DEL PROGRAMA',11(/))
      STOP
      ELSE
C***********************************************************************
C*                              SIMULACION                             *
C***********************************************************************
 0820 WRITE(*,830)
 0830 FORMAT(T38,'SIMULACION',/
     $       /,1X,'Temperaturas                             [01] ',
     $       /,1X,'Concentracin en la alimentacin lquida [02] ',
     $       /,1X,'Concentracin en la alimentacin gaseosa [03] ',
     $       /,1X,'Lectura del rotmetro                    [04] ',
     $       /,1X,'Cada de presin en la placa de orificio [05] ',
     $       /,1X,'Presin manomtrica del gas              [06] ',
     $       /,1X,'Altura del empaque                       [07] ',
     $       /,1X,'Ejecutar programa de absorcin           [08] ',
     $       /,1X,'Datos de equilibrio fsico-qumico       [09] ',
     $       /,1X,'Flujo de alimentacin del gas            [10] ',
     $       /,1X,'Flujo de alimentacin del lquido        [11] ',
     $       /,1X,'Flujo mnimo del lquido                 [12] ',
     $       /,1X,'Factor de empaque                        [13] ',
     $       /,1X,'Densidad del lquido                     [14] ',
     $       /,1X,'Finalizacin del programa                [15] ')
      READ(*,*,ERR=790)SM
      GOTO (840,940,980,1010,1030,1050,1130,1150,1160,1170,1180,1190,120
     $0,1210,1220)SM
      GOTO 790
 0840 WRITE(*,850)M
 0850 FORMAT(/,1X,'Valor anterior ',I1,/,1X,'Isotrmico[1], adiabtico[2
     $]  no-isotrmico[3] ? ')
      READ(*,*,ERR=840)M
      IF (M.LT.1.OR.M.GT.3) GOTO 840
      GOTO (860,900,880) M
 0860 WRITE(*,870)TA
 0870 FORMAT(/,1X,'Valor anterior ',G15.5,/,1X,'Temperatura del sistema
     $[K] = ? ')
      READ(*,*,ERR=860)TA
      TLA=TA
      TGA=TA
      IF (TLA.LE.273.15) GOTO 860
      GOTO 790
 0880 WRITE(*,890)TA
 0890 FORMAT(/,1X,'Valor anterior ',G15.5,/,1X,'Temperatura ambiente [K
     $] = ? ')
      READ(*,*,ERR=880)TA
      IF (TA.LE.0) GOTO 880
 0900 WRITE(*,910)TLA
 0910 FORMAT(/,1X,'Valor anterior ',G15.5,/,1X,'Temperatura de alimentac
     $in del lquido [K] = ? ')
      READ(*,*,ERR=900)TLA
      IF (TLA.LE.273.15) GOTO 900
 0920 WRITE(*,930)TGA
 0930 FORMAT(/,1X,'Valor anterior ',G15.5,/,1X,'Temperatura de alimentac
     $in del gas [K] = ? ')
      READ(*,*,ERR=920)TGA
      IF (TGA.LE.0) GOTO 920
      GOTO 790
 0940 WRITE(*,950)W1A
 0950 FORMAT(/,1X,'Valor anterior ',G10.4,/,1X,'Fraccin peso de la MEA
     $sin CO2 = ? ')
      READ(*,*,ERR=940)W1A
      IF (W1A.LT.0.OR.W1A.GT.1) GOTO 940
 0960 WRITE(*,970)Y2A
 0970 FORMAT(/,1X,'Valor anterior ',G10.4,/,1X,'Mol de CO2/Mol de MEA en
     $ la alimentacin = ? ')
      READ(*,*,ERR=960)Y2A
      IF (Y2A.LT.0) GOTO 960
      GOTO 790
 0980 DO I=1,2
 0990 WRITE(*,1000)YA(I),COMP(I)
 1000 FORMAT(/,1X,'Valor anterior ',G10.4,/,1X,'Frac. mol del ',A3,' en
     $el gas de alimentacin = ? ')
      READ(*,*,ERR=990)YA(I)
      IF (YA(I).LT.0.OR.YA(I).GT.1) GOTO 990
      END DO
      GOTO 790
 1010 WRITE(*,1020)LR
 1020 FORMAT(/,1X,'Valor anterior ',G10.2,/,1X,'Lectura del rotmetro =
     $? ')
      READ(*,*,ERR=1010)LR
      IF (LR.LT.1) GOTO 1010
      GOTO 790
 1030 WRITE(*,1040)DP
 1040 FORMAT(/,1X,'Valor anterior ',G10.2,/,1X,'Cada de presin en la p
     $laca de orificio [cmH2O] = ? ')
      READ(*,*,ERR=1030)DP
      IF (DP.LE.0) GOTO 1030
      GOTO 790
 1050 WRITE(*,1060)P1
 1060 FORMAT(/,1X,'Valor anterior ',G10.2,/,1X,'Presin manomtrica del
     $gase el manmetro [Kg/cm] = ? ')
      READ(*,*,ERR=1050)P1
      IF (P1.LE.0) GOTO 1050
      GOTO 790
 1130 WRITE(*,1140)ZT
 1140 FORMAT(/,1X,'Valor anterior ',G11.3,/,1X,'Altura del empaque [m] =
     $ ? ')
      READ(*,*,ERR=1130)ZT
      IF (ZT.LE.0) GOTO 1130
      GOTO 790
 1150 GOTO 350
 1160 CALL EQUILI
      GOTO 790
 1170 CALL CFG
      GOTO 790
 1180 CALL CFL
      GOTO 790
 1190 CALL CFLM
      GOTO 790
 1200 CALL FACTOR
      GOTO 790
 1210 CALL CDL
      GOTO 790
 1220 SC=2
      GOTO 790
      END IF
      ELSE
C***********************************************************************
C*  INICIAZION DE OTRA ITERACION ALMANCENANDO LAS FRACCIONES DEL CO2   *
C***********************************************************************
      SUM1=0
      DO I=1,NS
      YC(I)=Y(1,I)
      SUM1=SUM1+YC(I)
      END DO
      GOTO 380
      END IF
      END
C***********************************************************************
C*                            SUBRUTINA GRAFICA                        *
C***********************************************************************
      SUBROUTINE GRAFICA (NS,F,GRF)
      INTEGER NROW,NCOL,NCELL,R,K,S,NS,GRF
      PARAMETER (NROW=21,NCOL=70,NCELL=NCOL*NROW)
      REAL XINIT,XINCR,YMAX,YINCR,XFINL,YV(NCOL),YDIST,YMIN,XM
      CHARACTER *1 GRAPH(NROW,NCOL)
      DOUBLE PRECISION F(51)
      DATA GRAPH/NCELL*' '/
      XFINL=1
      XINIT=0
      XINCR=(XFINL-XINIT)/REAL(NCOL-1)
      YMAX=F(1)
      YMIN=F(1)
      DO K=1,NCOL
      XM=XINIT+(K-1)*XINCR
      S=NINT(XM*NS)
      IF (S.EQ.0) THEN
      YV(K)=F(1)
      ELSE
      YV(K)=F(S)
      END IF
      IF (YV(K).GT.YMAX) YMAX=YV(K)
      IF (YV(K).LT.YMIN) YMIN=YV(K)
      END DO
      YINCR=(YMAX-YMIN)/REAL(NROW-1)
      DO K=1,NCOL
      YDIST=(YMAX-YV(K))/YINCR
      R=NINT(YDIST+1)
      GRAPH(R,K) ='*'
      END DO
      CALL PRTGRH (GRAPH,XINIT,XINCR,YMAX,YINCR,GRF)
      DO I=1,NROW
      DO J=1,NCOL
      GRAPH(I,J)=' '
      END DO
      END DO
      RETURN
      END
C-----------------------------------------------------------------------
      SUBROUTINE PRTGRH (GRAPH,XINIT,XINCR,YMAX,YINCR,GRF)
      INTEGER NROW,NCOL,GRF
      PARAMETER (NROW=21,NCOL=70)
      CHARACTER GRAPH(NROW,NCOL)*1,COMND*10
      REAL XINIT,XINCR,YMAX,YINCR
      INTEGER R,K,L
      REAL YVAL,XVAL,XSCALE(9)
      K=7
      DO L=1,10
      XVAL=XINIT+(K-1)*XINCR
      XSCALE(L)=XVAL
      K=K+7
      END DO
      DO R=1,NROW
      IF (MOD(R,2).NE.0) THEN
      DO K=1,NCOL
      IF (GRAPH(R,K).NE.'*') GRAPH(R,K)=''
      IF (MOD(K,7).EQ.0.AND.GRAPH(R,K).NE.'*') GRAPH(R,K)=''
      END DO
      DO K=2,NCOL-1
      IF (MOD(K,7).EQ.0) THEN
      IF (GRAPH(1,K).NE.'*') GRAPH(1,K)=''
      IF (GRAPH(NROW,K).NE.'*') GRAPH(NROW,K)=''
      END IF
      END DO
      IF (GRAPH(R,NCOL).NE.'*') GRAPH(R,NCOL)=''
      IF (GRAPH(1,NCOL).NE.'*') GRAPH(1,NCOL)=''
      IF (GRAPH(R,1).NE.'*') GRAPH(R,1)=''
      IF (GRAPH(1,1).NE.'*') GRAPH(1,1)=''
      IF (GRAPH(NROW,1).NE.'*') GRAPH(NROW,1)=''
      IF (GRAPH(NROW,NCOL).NE.'*') GRAPH(NROW,NCOL)=''
      YVAL=YMAX-(R-1)*YINCR
      IF (GRF.EQ.1) THEN
      WRITE(*,10)YVAL,(GRAPH(R,K),K=1,NCOL)
      ELSE IF (GRF.EQ.2) THEN
      WRITE(*,20)YVAL,(GRAPH(R,K),K=1,NCOL)
      ELSE
      WRITE(*,30)YVAL,(GRAPH(R,K),K=1,NCOL)
      END IF
 0010 FORMAT(3X,F6.1,1X,70A1)
 0020 FORMAT(1X,F8.5,1X,70A1)
 0030 FORMAT(1X,F8.4,1X,70A1)
      ELSE
      DO K=1,NCOL
      IF (MOD(K,7).EQ.0.AND.GRAPH(R,K).NE.'*') GRAPH(R,K)=''
      END DO
      IF (GRAPH(R,1).NE.'*') GRAPH(R,1)=''
      WRITE(*,40)(GRAPH(R,K),K=1,NCOL)
 0040 FORMAT(10X,70A1)
      END IF
      END DO
      WRITE(*,50)XINIT,(XSCALE(L),L=1,10)
 0050 FORMAT(4X,11(1X,F6.1))
      COMND='PAUSE'
      CALL SYSTEM (COMND)
      RETURN
      END
C***********************************************************************
C*               CALCULO DE LA TEMPERATURA DEL LQUIDO                 *
C***********************************************************************
      SUBROUTINE TEMLIQ (TLE,CPL,LME,LMS,Q,QI,Z,A,HRT,TLS)
      DOUBLE PRECISION TLE,LME,LMS,Q,QI,Z,HRT,TLS,HLE,HLS,CPL,A
      CPL=CPL*1000
      HLE=CPL*(TLE-283.15D0)
      HLS=(HLE*LME-HRT*LMS+(QI*A-4*Q/78D-3)*Z)/LMS
      TLS=HLS/CPL+283.15D0
      RETURN
      END
C***********************************************************************
C*               FLUJOS MOLARES Y COMPOSICIONES DEL LIQUIDO            *
C***********************************************************************
      SUBROUTINE FLSMOL (XE,N,LME,Z,LMS,XS)
      DOUBLE PRECISION XE(3),N(2),Z,LMS,XS(3),LME
      LMS=LME+(N(1)+N(2))*Z
      XS(1)=(LME*XE(1)+N(1)*Z)/LMS
      XS(2)=(LME*XE(2)+N(2)*Z)/LMS
      XS(3)=LME*XE(3)/LMS
      RETURN
      END
C***********************************************************************
C*           CALCULO DE LA TEMPERATURA INTERFACIAL Y DEL GAS           *
C***********************************************************************
      SUBROUTINE TEMGAI (TG1,TL1,Y,YS,GME,GMS,A,Z,HG,HL,N,TF,TI,TG2,QI)
      DOUBLE PRECISION TG1,TG2,TL1,CP1,CP2,CP3,Y(3),GME,GMS,A,Z,TI,HG2,T
     $F,N(2),HG,HL,CO,QI,YS(3),CLV2
      Y(3)=1-Y(1)-Y(2)
      CP1=(19.8D0+7.344D-2*TG1-5.602D-5*TG1**2+1.715D-8*TG1**3)*1000
      CP2=(32.24D0+1.924D-3*TG1+1.055D-5*TG1**2-3.596D-9*TG1**3)*1000
      CP3=(30.415D0-1.059D-2*TG1+2.459D-5*TG1**2-1.136D-8*TG1**3)*1000
      CO=(CP1*N(1)+CP2*N(2))/(HG*A)
      IF (TG1.LT.TL1) THEN
      CO=-CO
      END IF
      TF=CO/(1-DEXP(-CO))
      TI=(HG*TG1*TF+HL*TL1)/(HG*TF+HL)
      CLV2=9717*4184*((1-TG1/647.3D0)/(1-373.2D0/647.3D0))**0.38D0
      QI=(HL*(TI-TL1)*A+N(2)*CLV2)*Z
      HG1=(TG1-283.15D0)*(Y(1)*CP1+Y(2)*CP2+Y(3)*CP3)+Y(2)*45285136.68D
     $0
      HG2=(GME*HG1-QI)/GMS
      TG2=(HG2-YS(2)*45287136.68D0)/(YS(1)*CP1+YS(2)*CP2+YS(3)*CP3)+283
     $.15D0
      QI=QI/(A*Z)
      RETURN
      END
C***********************************************************************
C*                FLUJO DE CALOR A TRAVEZ DE LA CORAZA                 *
C***********************************************************************
      SUBROUTINE FLUCAL (TA,TI,Q)
      DOUBLE PRECISION TA,TI,R2,R1,KA,DEN,NP,V,B,TS,DT,NG,C,M,H,KV,U,TSC
     $,Q,TP
      R2=0.088D0/2
      R1=R2-5D-3
      KV=1.09D0
      TS=TA-2
      B=1/TA
      TP=TA
 0010 KA=2.9D-3+7.76D-5*TP
      DEN=28.96D0/(0.082D0*TP)
      NP=0.784D0-2.5D-4*TP
      V=4.6786D-6+45.9D-9*TP
      DT=ABS(TS-TA)
      NG=0.088D0**3*DEN**2*9.80665D0*B*DT/V**2
      IF (NG*NP.GT.0.AND.NG*NP.LE.10D4) THEN
      C=1.272D0
      M=0.128D0
      ELSE IF (NG*NP.GT.10D4.AND.NG*NP.LT.10D9) THEN
      C=0.525D0
      M=1/4D0
      ELSE
      C=0.129D0
      M=1/3D0
      END IF
      H=KA*C*(NG*NP)**M/0.088D0
      U=1/(R2*DLOG(R2/R1)/KV+1/H)
      TSC=U*(TI-TA)/H+TA
      IF (ABS(TSC-TS).LT.1D-1) THEN
      Q=U*(TI-TA)
      RETURN
      ELSE
      TP=(TSC+TA)/2
      TS=TSC
      GOTO 10
      END IF
      END
C***********************************************************************
C*               FLUJOS MOLARES Y COMPOSICIONES DEL GAS                *
C***********************************************************************
      SUBROUTINE FGSMOL (YE,N,GME,Z,GMS,YS)
      DOUBLE PRECISION GME,GMS,YE(3),YS(3),N(2),Z
      YE(3)=1-YE(1)-YE(2)
      GMS=GME-(N(1)+N(2))*Z
      YS(1)=(GME*YE(1)-N(1)*Z)/GMS
      YS(2)=(GME*YE(2)-N(2)*Z)/GMS
      YS(3)=GME*YE(3)/GMS
      RETURN
      END
C***********************************************************************
C*          CONCENTRACIONES INTERFACIALES CON REACCIN QUMICA         *
C***********************************************************************
      SUBROUTINE CONIN2 (T,P,LM,GM,HTUL,HTUG,YB,XB,DIFL,AINT,CTLI,CTLB,N
     $,EC,YI,XI,HA)
      DOUBLE PRECISION HTUL(2),HTUG(2),LM,GM,T,P,CTLI,CTLB,DIFL(3),AINT,
     $YB(2),XB(3),E,EC,HA,A,N2,XI,YI,N(2),H,KT,F,FD,Z,H2,FC1,FC2,V
      F(Z)=(1-YB(1)*FC1)*DEXP(E*LM*(Z/H-XB(1))*HTUG(1)*FC1/(GM*HTUL(1)))
     $-1+Z*FC1
      DIFL(2)=DIFL(3)
      KT=XB(2)*CTLB*10**(10.99D0-2152/T)
      HA=CTLI*HTUL(1)*AINT*DSQRT(KT*DIFL(1))/LM
      H=DEXP(22.2819D0-13.830611D3/T+6.913457D6/T**2-1.558951D9/T**3+0.1
     $20037D12/T**4)*1.01325D0/760
      H=H*CTLI/P
      H2=DEXP(16.5362D0-3985.44D0/(T-38.9974D0))*1.01325D0/101.325D0
      H2=H2/P
      FC1=1
      FC2=1
      E=1
      D=1D-8
      YI=YB(1)
 0010 FD=(F(YI+D)-F(YI))/D
      YI=YI-F(YI)/FD
      IF (ABS(F(YI)).LT.1D-6) THEN
      XI=YI/H
      N2=DIFL(2)*XB(2)*CTLB/(2*DIFL(1)*XI*CTLI)
      A=HA/N2+DEXP(0.68D0/HA-0.45D0*HA/N2)
      EC=1+HA/A*(1-DEXP(-0.65D0*HA*DSQRT(A)))
      N(1)=LM*EC*(XI-XB(1))/HTUL(1)
      V=(1-FC2*H2*XB(3))/(1-FC2*YB(2))
      IF (V.LE.0) THEN
      V=(1-H2*XB(3))/(1-YB(2))
      END IF
      N(2)=GM*DLOG(V)/(HTUG(2)*FC2)
      FC1=(N(1)+N(2))/N(1)
      FC2=(N(1)+N(2))/N(2)
      IF (ABS(EC-E)/E.LT.1D-3) THEN
      RETURN
      ELSE
      E=EC
      GOTO 10
      END IF
      ELSE
      GOTO 10
      END IF
      END
C***********************************************************************
C*        CALCULO DE LA ALTURA DE UNA UNIDAD DE TRANSFERENCIA DE       *
C*                           LA FASE LIQUIDA                           *
C***********************************************************************
      SUBROUTINE HTULIQ (VML,DML,DIFL,PIN,LM,Z,HTUL)
      DOUBLE PRECISION LM,VML,DML,DIFL(3),Z,PIN,SCL(2),CFL,PE,HTUL(2)
      SCL(1)=VML/(DML*DIFL(1))
      SCL(2)=VML/(DML*DIFL(2))
      LM=LM*0.3048D0**2*3600/0.454D0
      IF (LM.LE.1000) THEN
      PE=0.0159766D0-1.684019999D-5*LM+1.244599999D-8*LM**2
      ELSE
      PE=0.01073595111D0+2.075295812D-6*LM-9.224090745D-12*LM**2
      END IF
      IF (PIN.LT.50) THEN
      CFL=1
      ELSE
      CFL=-5.032503291D0+0.2838033129*PIN-4.270144594D-3*PIN**2+1.995296
     $621D-5*PIN**3
      END IF
      DO I=1,2
      HTUL(I)=PE*CFL*(Z/3.048D0)**0.15D0*SCL(I)**0.5D0
      END DO
      LM=LM*0.454D0/(0.3048D0**2*3600)
      RETURN
      END
C***********************************************************************
C*        CALCULO DE LA ALTURA DE UNA UNIDAD DE TRANSFERENCIA DE       *
C*                            LA FASE VAPOR                            *
C***********************************************************************
      SUBROUTINE HTUGAS (TL,LM,Z,VML,DML,TSM,DMG,VMG,DIFM,PIN,HTUG)
      DOUBLE PRECISION TL,VML,V2,DML,D2,TSM,TS2,VMG,DMG,FV,DIFM(3),FD,FT
     $,SCV(2),LM,PE,PIN,HTUG(2),Z
      V2=DEXP(-24.71D0+4209D0/TL+0.04527D0*TL-3.376D-5*TL**2)/1000
      FV=(VML/V2)**0.16D0
      D2=810.8397753D0+1.544995123D0*TL-3.084391807D-3*TL**2
      FD=(DML/D2)**(-1.25D0)
      TS2=(94.89732907D0+1.150899495D-3*TL-2.620535127D-4*TL**2)/1000
      FT=(TSM/TS2)**(-0.8D0)
      SCV(1)=VMG/(DMG*DIFM(1))
      SCV(2)=VMG/(DMG*DIFM(2))
      PE=(39.06428571D0+4.632857143D0*PIN-0.0425D0*PIN**2)*0.3048D0
      DO I=1,2
      HTUG(I)=(PE*(0.0780288D0/0.3048D0)**1.24D0*(Z/3.048D0)**(1/3D0)*SC
     $V(I)**0.5D0)/(737.34D0*LM*FV*FD*FT)**0.6D0
      END DO
      RETURN
      END
C***********************************************************************
C*            COEFICIENTE DE TRANSFERENCIA DE CALOR DEL LIQUIDO        *
C***********************************************************************
      SUBROUTINE CTCLIQ (CPM,VM,CTM,X1,L,CTCL)
      DOUBLE PRECISION CPM,CTM,VM,PR,L,CTCL,PMM,X1
      PMM=X1*61.084D0+(1-X1)*18.015D0
      CPM=1000*CPM/PMM
      PR=CPM*VM/CTM
      CTCL=25.1D0*CTM*(0.01774D0*L/VM)**0.45D0*DSQRT(PR)/0.01774D0
      CPM=CPM*PMM/1000
      RETURN
      END
C***********************************************************************
C*            COEFICIENTE DE TRANSFERENCIA DE CALOR DEL GAS            *
C***********************************************************************
      SUBROUTINE CTCGAS (CPM,VMG,CTM,RLT,Y,G,CTCG)
      DOUBLE PRECISION Y(5),VMG,G,CPM,CTM,RLT,PMM,M(5),PR,ELO,CTCG
      OPEN(1,FILE='PESO-MOL.DAT')
      PMM=0
      DO I=1,5
      READ(1,*)M(I)
      PMM=PMM+M(I)*Y(I)
      END DO
      CPM=1000*CPM/PMM
      PR=CPM*VMG/CTM
      ELO=0.634D0-RLT
      CTCG=1.195D0*CPM*G*(0.01774D0*G/(VMG*(1-ELO)))**(-0.36D0)/PR**(2/3
     $D0)
      REWIND 1
      CPM=CPM*PMM/1000
      RETURN
      END
C***********************************************************************
C*        CALCULO DE LA RETENCION TOTAL DEL LIQUIDO EN LA COLUMNA      *
C***********************************************************************
      SUBROUTINE RETLIQ (DML,TS,VML,L,RT)
      DOUBLE PRECISION DML,L,VML,TS,RT,RO,RE,REA,RTA,ROA,H,CH1,CH2,B
      B=0.3311371457D0
      REA=2.47D-4/0.01774D0**1.21D0
      RTA=2.09D-6*(737.5D0*L)**B/0.01774D0**2
      ROA=RTA-REA
      IF (VML.LT.0.012) THEN
      CH1=975.7D0
      CH2=0.13D0
      ELSE
      CH1=2168
      CH2=0.31D0
      END IF
      H=CH1*L**0.57D0*VML**CH2*(TS/.073D0)**(0.1737D0-0.262D0*DLOG10(L))
     $/(DML**0.84D0*(2.024D0*L**0.43D0-1))
      RO=ROA*H
      RE=0.0486D0*VML**0.02D0*TS**0.99D0/(0.01774D0**1.21D0*DML**0.37D0)
      RT=RE+RO
      RETURN
      END
C***********************************************************************
C*          CLCULO DE LA CADA DE PRESIN EN COLUMNAS EMPACADAS       *
C***********************************************************************
      SUBROUTINE CAIPRE (DG,DL,WG,WL,PC,PIN,*,*)
      DOUBLE PRECISION A(8),B(8),Y(8),P(8),DG,DL,WG,WL,PC,YC,X,F,P1,P2,Y
     $1,Y2,PIN
      CHARACTER COMND*10
      DATA A/0.25D0,0.165D0,0.125D0,0.073D0,0.034D0,0.017D0,0.007D0,0.00
     $13D0/
      DATA B/1.3D0,1.1D0,1.0D0,0.9D0,0.77D0,0.6D0,0.42D0,0.235D0/
      DATA P/0D0,1.5D0,1D0,0.5D0,0.2D0,0.1D0,0.05D0,0.01D0/
      COMND='CLS'
      WG=WG*3600/0.454D0
      WL=WL*3600/0.454D0
      DG=DG*30.48D0**3/(0.454D0*100**3)
      DL=DL*30.48D0**3/(0.454D0*100**3)
      X=WL*DSQRT(DG/DL)/WG
      DO I=1,8
      Y(I)=A(I)/(1+(B(I)*X)**0.65D0)**(1/0.325D0)
      END DO
      WG=WG*4/(3600*3.141592654D0*0.256D0**2)
C*    F= FACTOR DE EMPAQUE
      F=1584
      YC=WG**2*F/(32.174D0*DG*DL)
      IF (YC.GT.Y(2)) THEN
      CALL SYSTEM (COMND)
      WRITE(*,10)
 0010 FORMAT(9(/),T37,' ATENCIN !',//,1X,'Los flujos de  gas y lquido
     $ especificados corresponden a las condiciones de 100% de inundaci
     $n, en los cuales la columna no puede operar correctamente,  por lo
     $que se recomienda disminuirlos.',9(/))
      COMND='PAUSE'
      CALL SYSTEM (COMND)
      RETURN 2
      END IF
      IF (YC.LT.Y(8)) THEN
      CALL SYSTEM (COMND)
      WRITE(*,20)
 0020 FORMAT(10(/),T37,' ATENCIN !',//1X,'La cada de presin es pract
     $icamente igual a "cero".',10(/))
      COMND='PAUSE'
      CALL SYSTEM (COMND)
      RETURN 2
      END IF
      DO I=2,7
      IF (YC.LT.Y(I).AND.YC.GT.Y(I+1)) THEN
      Y1=Y(I)
      Y2=Y(I+1)
      P1=P(I)
      P2=P(I+1)
      END IF
      END DO
      PC=P1*(P2/P1)**(DLOG10(Y1/YC)/DLOG10(Y1/Y2))
      PIN=100*(YC/Y(1))**(1/2D0)
      COMND='CLS'
      CALL SYSTEM (COMND)
      WRITE(*,30)PIN
  030 FORMAT(9(/),20X,'EL PORCIENTO DE INUNDACIN ES ',G12.4,//)
  040 WRITE(*,50)
  050 FORMAT(6X,' Desea continuar [1] o cambiar alguna especificacin [
     $2] ? ')
      READ(*,*,ERR=40)RSP
      IF (RSP.EQ.1) THEN
      GOTO 60
      ELSE IF (RSP.EQ.2) THEN
      RETURN 2
      ELSE
      GOTO 40
      END IF
  060 DL=0.454D0*100**3*DL/30.48D0**3
      DG=0.454D0*100**3*DG/30.48D0**3
      WL=0.454D0*WL/3600
      WG=0.454D0*0.256D0**2*3.141592654D0*WG/4
      RETURN 1
      END
C***********************************************************************
C*                     CALCULO DEL AREA INTERFACIAL                    *
C***********************************************************************
      SUBROUTINE AREA (L,G,DML,TS,VML,DG,AIL)
      DOUBLE PRECISION AIA,AIL,H,M,N,P,DML,TS,VML,L,DG,G,CH1,CH2
      IF (VML.LT.0.012) THEN
      CH1=975.7D0
      CH2=0.13D0
      ELSE
      CH1=2168
      CH2=0.31D0
      END IF
      H=CH1*L**0.57D0*VML**CH2*(TS/.073D0)**(0.1737D0-0.262D0*DLOG10(L))
     $/(DML**0.84D0*(2.024D0*L**0.43D0-1))
      IF (L.LE.2) THEN
      M=28.01D0
      N=0.2323D0*L-0.3D0
      P=-1.04D0
      ELSE
      M=14.69D0
      N=0.01114D0*L+0.148D0
      P=-0.111D0
      END IF
      AIA=M*(808*G/DG**0.5D0)**N*L**P
      AIL=AIA*H
      RETURN
      END
C***********************************************************************
C*                             FLUJO DEL GAS                           *
C***********************************************************************
      SUBROUTINE FLUGAS (Y,P,DP,DM,CP,VM,WG,WAG,WAMG)
      DOUBLE PRECISION P,DP,DM,WG,WAG,WAMG,CP,CV,K,YC,B,VM,NRE,R,CC,PMG,
     $C,M(5),Y(5)
      DP=DP*14.696D0/(2.54D0*406.8D0)
      OPEN(1,FILE='PESO-MOL.DAT')
      DO I=1,5
      READ(1,*)M(I)
      END DO
      PMG=0
      DO I=1,5
      PMG=PMG+Y(I)*M(I)
      END DO
      REWIND 1
      DM=DM*30.48D0**3/(0.454D0*100**3)
      CV=CP-8.3144D0
      VM=VM*30.48D0*3600/(0.454D0*100)
      K=CP/CV
      B=0.375D0/1.0118D0
      R=1-1.01325D0*DP/(P*14.696D0)
      YC=1-((1-R)/K)*(0.41D0+0.35D0*B**4)
      C=0.604D0
 0010 WG=1891*YC*(3D0/8D0)**2*C*DSQRT(DP*DM)
      NRE=4*WG/(3.141592654D0*VM*2.57D0/(2.54D0*12))
      CC=0.593D0+0.4D0*B**4+(1.5D0*DSQRT(B)+12*B**4)/DSQRT(NRE)
      IF (ABS(CC-C).LT.0.001) THEN
      C=CC
      WG=WG*0.454D0/3600
      WAG=WG/(3.141592654D0*7.8D-2**2/4)
      WAMG=WAG/PMG
      DM=0.454D0*100**3*DM/(30.48D0**3)
      VM=0.454D0*100*VM/(3600*30.48D0)
      REWIND 1
      RETURN
      ELSE
      C=CC
      GOTO 10
      END IF
      END
C***********************************************************************
C*                    CLCULO DEL FLUJO DEL LQUIDO                    *
C***********************************************************************
      SUBROUTINE FLULIQ (W1,X1,LEC,DM,W,WA,WAM)
      DOUBLE PRECISION W1,X1,LEC,DM,W,WA,WAM,PM
      PM=X1*61.084D0+(1-X1)*18.015D0
      W=(5.311124202D0*LEC-1.0266523946D0*W1-3.382885102D0)*DM/1D6
      WA=W/(3.141592654D0*7.8D-2**2/4)
      WAM=WA/PM
      RETURN
      END
C***********************************************************************
C*                            CALOR DE SOLUCION                        *
C***********************************************************************
      SUBROUTINE CALSOL(T,CE,CTLB,HRT)
      DOUBLE PRECISION T,CE(8),A(5),B(5),C(5),D(5),E(5),TB(5),TC(5),HG(5
     $),CLV(5),HL(5),HR1,HR2,HRT,CLVR(5),CTLB
      DATA A/-51670,-60135.8D0,-96130,-229500,-229500/
      DATA B/2.224D0,7.701D0,4.728D0,20.26D0,20.26D0/
      DATA C/35.94D-3,0.22975D-3,8.77D-3,61.4D-3,61.4D-3/
      DATA D/-14.47D-6,0.84033D-6,-4.46D-6,-14D-6,-14D-6/
      DATA E/2.78D-9,-0.21475D-9,1.024D-9,-1.3D-9,-1.3D-9/
      DATA TB/443.5D0,373.2D0,194.7D0,350,350/
      DATA TC/614,647.3D0,304.3D0,420,420/
      DATA CLVR/12000,9717,4100,17000,15000/
      DO I=1,5
      HG(I)=A(I)+B(I)*T+C(I)*T**2+D(I)*T**3+E(I)*T**4
      IF (T.GT.TC(I)) THEN
      CLV(I)=0
      ELSE
      CLV(I)=CLVR(I)*((1-T/TC(I))/(1-TB(I)/TC(I)))**0.38D0
      END IF
      HL(I)=HG(I)-CLV(I)
      END DO
      HR1=CE(4)*(HL(4)-HL(3)-2*HL(1))
      HR2=(CE(6)+CE(7))*(HL(5)-HL(1)-HL(2)-HL(3))
      HRT=HR1+HR2
      HRT=4184*HRT/CTLB
      RETURN
      END
C***********************************************************************
C*                       EQUILIBRIO FISICOQUIMICO                      *
C***********************************************************************
      SUBROUTINE EQUQUI (T,W1,Y2,DML,CE,CTLB)
      DOUBLE PRECISION X(4),T,C1,Y2,W1,DML,C5,Y5,CE(8),CTLB
      C1=W1*DML/61.084D0
      C5=(1-W1)*DML/18.015D0
      Y5=C5/C1
      CALL NEWMULT (X,T,C1,Y2)
      CE(1)=(1-X(1)-X(2)-X(3)-X(4))*C1
      CE(2)=(Y2-.5D0*X(1)-X(2))*C1
      CE(3)=(.5D0*X(1)+X(2)+X(3)+X(4))*C1
      CE(4)=.5D0*X(1)*C1
      CE(5)=(Y5-X(2)-X(4))*C1
      CE(6)=(X(2)-X(3))*C1
      CE(7)=X(3)*C1
      CE(8)=X(4)*C1
      CTLB=0
      DO I=1,8
      CTLB=CTLB+CE(I)
      END DO
      RETURN
      END
C**********************************************************************
C*                 SUBRUTINA NEWTON-RAPHSON MULTIVARIABLE             *
C**********************************************************************
      SUBROUTINE NEWMULT (X,T,C1,Y2)
      DOUBLE PRECISION X(4),F(4),B,H,T,C1,Y2,XT,SUM
      COMMON B(4,5)
      XT=1D-6
      DO I=1,4
      X(I)=XT
      END DO
 0010 H=1D-10
 0020 DO I=1,4
      DO J=1,5
      IF (J.EQ.5) THEN
      B(I,J)=F(I)
      GOTO 30
      END IF
      X(J)=X(J)+H
      CALL KTES(F,X,T,C1,Y2)
      B(I,J)=F(I)
      X(J)=X(J)-H
      CALL KTES(F,X,T,C1,Y2)
      B(I,J)=(B(I,J)-F(I))/H
      END DO
 0030 CONTINUE
      END DO
      CALL GAUSS
      DO I=1,4
      X(I)=X(I)-B(I,5)
      END DO
      CALL KTES(F,X,T,C1,Y2)
      SUM=0
      DO I=1,4
      SUM= SUM+F(I)
      END DO
      IF (ABS(SUM).LT.1D-6) THEN
      IF (X(1)*X(2).LT.0.OR.X(1)*X(3).LT.0.OR.X(2)*X(3).LT.0.OR.X(1)*X(4
     $).LT.0.OR.X(2)*X(4).LT.0.OR.X(3)*X(4).LT.0) THEN
      IF (Y2.LT.1D-2) THEN
      XT=XT+5D-5
      ELSE
      XT=XT+5D-3
      END IF
      DO I=1,4
      X(I)=XT
      END DO
      GOTO 10
      ELSE
      GOTO 40
      END IF
      END IF
      GOTO 20
 0040 RETURN
      END
C**********************************************************************
C*                         SUBRUTINA GAUSS-JORDAN                     *
C**********************************************************************
      SUBROUTINE GAUSS
      DOUBLE PRECISION A,TEM,TEMP
      COMMON A(4,5)
      DO 30 K=1,4
      M=1
 0010 IF (A(K,K).EQ.0) THEN
      DO L=1,5
      TEM=A(K,L)
      A(K,L)=A(K+M,L)
      A(K+M,L)=TEM
      END DO
      IF (M.GT.(4-K)) THEN
      WRITE(*,*)'No existe solucin nica'
      STOP
      END IF
      M=M+1
      GOTO 10
      END IF
      TEMP=A(K,K)
      DO J=1,5
      A(K,J)=A(K,J)/TEMP
      END DO
      DO I=1,4
      IF (I.EQ.K) GOTO 20
      TEMP= A(I,K)
      DO J=1,5
      A(I,J)=A(I,J)-TEMP*A(K,J)
      END DO
 0020 CONTINUE
      END DO
 0030 CONTINUE
      RETURN
      END
C***********************************************************************
C*                       CONSTANTES DE EQUILIBRIO                      *
C***********************************************************************
      SUBROUTINE KTES(F,X,T,C1,Y2)
      DOUBLE PRECISION F(4),X(4),T,C1,Y2
      F(1)=DEXP(-245.14865D0+307.194717D3/T-148.527778D6/T**2+33.264746D
     $9/T**3-2.823931D12/T**4)*2*C1*(Y2-.5D0*X(1)-X(2))*(1-X(1)-X(2)-X(3
     $)-X(4))**2-X(1)*(.5D0*X(1)+X(2)+X(3)+X(4))
      F(2)=DEXP(-238.4544D0+304.103889D3/T-148.527778D6/T**2+33.264746D9
     $/T**3-2.823931D12/T**4)*(1-X(1)-X(2)-X(3)-X(4))*(Y2-.5D0*X(1)-X(2)
     $)-(.5D0*X(1)+X(2)+X(3)+X(4))*(X(2)-X(3))
      F(3)=DEXP(-291.3764D0+370.236111D3/T-184.157407D6/T**2+41.579218D9
     $/T**3-3.542905D12/T**4)*(1-X(1)-X(2)-X(3)-X(4))*(X(2)-X(3))-X(3)*(
     $.5D0*X(1)+X(2)+X(3)+X(4))
      F(4)=DEXP(42.919D0-92.938889D3/T+56.882716D6/T**2-14.645062D9/T**3
     $+1.361454D12/T**4)*(1-X(1)-X(2)-X(3)-X(4))-C1*X(4)*(.5D0*X(1)+X(2)
     $+X(3)+X(4))
      RETURN
      END
C***********************************************************************
C*             CALCULO DE LA VISCOSIDAD DE LA FASE LIQUIDA             *
C***********************************************************************
      SUBROUTINE VISLIQ (T,X1,VM)
      DOUBLE PRECISION T,G,V1,V2,X1,VM
      G=3.7210D2-3.11D0*T+8.8092D-3*T**2-8.3457D-6*T**3
      V1=DEXP(-3.9356D0+1010.8D0/(T-151.17D0))
      V2=DEXP(-24.71D0+4209D0/T+0.04527D0*T-3.376D-5*T**2)
      VM=DEXP(X1*DLOG(V1)+(1-X1)*DLOG(V2)+X1*(1-X1)*G)/1000
      RETURN
      END
C***********************************************************************
C*       CALCULO DE LA DIFUSIVIDAD DEL CO2 EN SOLUCION ACUOSA DE MEA   *
C***********************************************************************
      SUBROUTINE DIFLIQ (T,W1,X1,VM,DML,DIFL)
      DOUBLE PRECISION T,X1,VH2O,VM,DCO2A,DNO2A,DNO2S,DIFL(3),DAB,DBA,VM
     $EA,DML,C,W1
      VH2O=DEXP(-24.71D0+4209D0/T+0.04527D0*T-3.376D-5*T**2)/1000
      DCO2A=2.35D-6*DEXP(-2.119D3/T)
      DNO2A=5.07D-6*DEXP(-2.371D3/T)
      DNO2S=DNO2A*(VH2O/VM)**8D-1
      DIFL(1)=DCO2A*DNO2S/DNO2A
      VMEA=DEXP(-3.9356D0+1010.8D0/(T-151.17D0))
      VH2O=VH2O*1000
      DAB=8.93D-8*67.99568D0**0.267D0*T*(0.02516948D0/0.05883821D0)**0.
     $15D0/(18.80713D0**0.433D0*VMEA)
      DBA=8.93D-8*18.80713D0**0.267D0*T*(0.05883821D0/0.02516948D0)**0.
     $15D0/(67.99568D0**0.433D0*VH2O)
      DIFL(2)=(DAB**X1*DBA**(1-X1))/10000
      C=1000*W1*DML/61.084D0
      DIFL(3)=DEXP(-13.275D0-2198.3D0/T-7.8142D-5*C)
      RETURN
      END
C***********************************************************************
C*                 CALCULO DE LA DENSIDAD DE LA FASE LIQUIDA           *
C***********************************************************************
      SUBROUTINE DENLIQ (T,X1,DM)
      DOUBLE PRECISION T,X1,D1,D2,VE,VM,DM
      D1=(1283.609904D0-0.9829456948D0*T+2.576495034D-4*T**2)/1D3
      D2=(810.8397753D0+1.544995123D0*T-3.084391807D-3*T**2)/1D3
      VE=(X1-X1**2)*(20.963D0-0.18249D0*T+3.29582D-4*T**2+(2*X1-1)*(23.0
     $844D0-0.197554D0*T+3.70423D-4*T**2))
      VM=VE+X1*61.084D0/D1+(1-X1)*18.015D0/D2
      DM=(X1*61.084D0+(1-X1)*18.015D0)/VM*1000
      RETURN
      END
C***********************************************************************
C*                CONDUCTIVIDAD TERMICA DE LA FASE LIQUIDA             *
C***********************************************************************
      SUBROUTINE CTLIQ (T,W1,CTM)
      DOUBLE PRECISION T,W1,CT1,CT2,CTM
      CT1=0.27719D0-1.2509D-4*T
      CT2=-3.838D-1+5.254D-3*T-6.369D-6*T**2
      CTM=W1*CT1+(1-W1)*CT2-0.72D0*W1*(1-W1)*(CT2-CT1)
      RETURN
      END
C***********************************************************************
C*                CAPACIDAD CALORIFICA DE LA FASE LIQUIDA              *
C***********************************************************************
      SUBROUTINE CPLIQ (T,X1,CPM)
      DOUBLE PRECISION T,X1,CP1,CP2,CPM
      CP1=(2736.114D0-27.600426D0*T+0.0960672D0*T**2-1.088D-4*T**3)
      CP2=(17.310744D0+2.48375D-3*T-3.5766D-6*T**2)*4.184D0
      CPM=X1*CP1+(1-X1)*CP2
      RETURN
      END
C***********************************************************************
C*    CALCULO DE LA TENSION SUPERFICIAL CON EL METODO DE "PARACHOR"    *
C***********************************************************************
      SUBROUTINE TENSUP (T,X1,TS)
      DOUBLE PRECISION D1,DM1,TS1,TS2,X1,VM1,VM2,T,B,W,C,FVS1,FVS2,TS
      D1=(1283.609904D0-0.9829456948D0*T+2.576495034D-4*T**2)/1000
      DM1=D1/61.084D0
      VM1=1/DM1
      TS1=(152.3D0*DM1)**4
      TS2=94.89732907D0+1.150899495D-3*T-2.620535127D-4*T**2
      IF (X1.EQ.1) THEN
      TS1=TS1/1000
      TS=TS1
      TS2=TS2/1000
      GOTO 10
      END IF
      IF (X1.EQ.0) THEN
      TS2=TS2/1000
      TS=TS2
      TS1=TS1/1000
      GOTO 10
      END IF
      D2=(810.8397753D0+1.544995123D0*T-3.084391807D-3*T**2)/1000
      VM2=18.015D0/D2
      B=DLOG10(((1-X1)*VM2)**2/(X1*VM1))
      W=0.441D0*2*(TS1*VM1**(2/3D0)/2-TS2*VM2**(2/3D0))/T
      C=B+W
      FVS1=1/(10**C+1)
      FVS2=1-FVS1
      TS=((FVS2*TS2**(1/4D0)+FVS1*TS1**(1/4D0))**4)/1000
      TS1=TS1/1000
      TS2=TS2/1000
 0010 CONTINUE
      RETURN
      END
C***********************************************************************
C*             CALCULO DE LA VISCOSIDAD DE LA FASE GASEOSA             *
C*                       CON EL METODO DE CHUNG                        *
C***********************************************************************
      SUBROUTINE VISGAS (T,P,Y,VISM)
      DOUBLE PRECISION TC(5,5),W(5,5),VC(5,5),T,P,Y(5),M(5,5),SIG(5,5),E
     $PS(5,5),KP(5,5),VM,DMM,SIG3M,SIG2M,EPSM,MM,WM,TCM,VCM,MD(5,5),MD4M
     $,MDRM,FCM,KPM,TM,OMEGA,VISM2,E1,E2,E3,E4,E5,E6,E7,E8,E9,E10,YM,G1,
     $G2,VISM1,VISM,DM
      OPEN(1,FILE='VOL-CRI.DAT')
      OPEN(2,FILE='TEM-CRI.DAT')
      OPEN(3,FILE='K-AL-PO.DAT')
      OPEN(4,FILE='MOM-DIP.DAT')
      OPEN(5,FILE='PESO-MOL.DAT')
      OPEN(6,FILE='FAC-ACE.DAT')
      DO I=1,5
      READ(1,*)VC(I,I)
      READ(2,*)TC(I,I)
      READ(3,*)KP(I,I)
      READ(4,*)MD(I,I)
      READ(5,*)M(I,I)
      READ(6,*)W(I,I)
      END DO
      DO I=1,5
      SIG(I,I)=8.09D-1*VC(I,I)**(1/3D0)
      EPS(I,I)=TC(I,I)/1.2593D0
      END DO
      DO I=1,5
      DO J=1,5
      EPS(I,J)=DSQRT(EPS(I,I)*EPS(J,J))
      SIG(I,J)=DSQRT(SIG(I,I)*SIG(J,J))
      M(I,J)=2*M(I,I)*M(J,J)/(M(I,I)+M(J,J))
      KP(I,J)=DSQRT(KP(I,I)*KP(J,J))
      W(I,J)=(W(I,I)+W(J,J))/2
      END DO
      END DO
      SIG3M=0
      EPSM=0
      MM=0
      WM=0
      MD4M=0
      KPM=0
      DO I=1,5
      DO J=1,5
      SIG3M=SIG3M+Y(I)*Y(J)*SIG(I,J)**3
      EPSM=EPSM+Y(I)*Y(J)*EPS(I,J)*SIG(I,J)**3
      MM=MM+Y(I)*Y(J)*EPS(I,J)*SIG(I,J)**2*DSQRT(M(I,J))
      WM=WM+Y(I)*Y(J)*W(I,J)*SIG(I,J)**3
      MD4M=MD4M+Y(I)*Y(J)*(MD(I,I)*MD(J,J))**2/SIG(I,J)**3
      KPM=KPM+Y(I)*Y(J)*KP(I,J)
      END DO
      END DO
      SIG2M=SIG3M**(2D0/3D0)
      EPSM=EPSM/SIG3M
      MM=(MM/(EPSM*SIG2M))**2
      WM=WM/SIG3M
      MD4M=MD4M*SIG3M
      TCM=1.2593D0*EPSM
      VCM=SIG3M/8.09D-1**3
      MDRM=131.1D0*MD4M**(1/4D0)/DSQRT(VCM*TCM)
      FCM=1-2.75D-1*WM+5.9035D-2*MDRM**4+KPM
      TM=T/EPSM
      OMEGA=1.16145D0*TM**(-0.14874D0)+0.52487D0*DEXP(-0.7732D0*TM)+2.16
     $178D0*DEXP(-2.43787D0*TM)
      E1=6.324D0+50.412D0*WM-51.68D0*MDRM**4+1189D0*KPM
      E2=1.21D-3-1.154D-3*WM-6.257D-3*MDRM**4+3.728D-2*KPM
      E3=5.283D0+254.209D0*WM-168.48D0*MDRM**4+3898*KPM
      E4=6.623D0+38.096D0*WM-8.464D0*MDRM**4+31.42D0*KPM
      E5=19.745D0+7.63D0*WM-14.354D0*MDRM**4+31.53D0*KPM
      E6=-1.9D0-12.537D0*WM+4.985D0*MDRM**4-18.15D0*KPM
      E7=24.275D0+3.45D0*WM-11.291D0*MDRM**4+69.35D0*KPM
      E8=0.7972D0+1.117D0*WM+1.235D-2*MDRM**4-4.117D0*KPM
      E9=-0.2382D0+6.77D-2*WM-0.8163D0*MDRM**4+4.025D0*KPM
      E10=6.863D-2+0.3479D0*WM+0.5926D0*MDRM**4-0.727D0*KPM
      PMM=0
      DO I=1,5
      PMM=PMM+Y(I)*M(I,I)
      END DO
      CALL DENGAS (T,P,Y,DM)
      VM=PMM/DM*1D3
      DMM=1/VM
      YM=DMM*VCM/6D0
      G1=(1-0.5D0*YM)/(1-YM)**3
      G2=(E1*(1-DEXP(-E4*YM))/YM+E2*G1*DEXP(E5*YM)+E3*G1)/(E1*E4+E2+E3)
      VISM2=E7*YM**2*G2*DEXP(E8+E9/TM+E10/TM**2)
      VISM1=DSQRT(TM)*FCM*(1/G2+E6*YM)/OMEGA+VISM2
      VISM=(VISM1*36.344D0*DSQRT(MM*TCM)/VCM**(2D0/3D0))/10D6
      REWIND 1
      REWIND 2
      REWIND 3
      REWIND 4
      REWIND 5
      REWIND 6
      RETURN
      END
C***********************************************************************
C*                 DIFUSION MULTICOMPONETE EN FASE GAS                 *
C***********************************************************************
      SUBROUTINE DIFGAS (T,P,Y,DIFM)
      DOUBLE PRECISION D(3,3),M(3),DC(3,3),PE(3,3),IC(3,3),TBM,Y(5),DIFM
     $(3),T,P
      Y(3)=Y(3)+Y(4)+Y(5)
      OPEN(1,FILE='DIA-COL.DAT')
      OPEN(2,FILE='PAR-ENE.DAT')
      OPEN(3,FILE='PES-MOLD.DAT')
      DO I=1,3
      READ(1,*)DC(I,I)
      READ(2,*)PE(I,I)
      READ(3,*)M(I)
      END DO
      DO I=1,3
      DO 10 J=1,3
      IF (I.EQ.J) GOTO 10
      PE(I,J)=DSQRT(PE(I,I)*PE(J,J))
      DC(I,J)=(DC(I,I)+DC(J,J))/2D0
      TBM=T/PE(I,J)
      IC(I,J)=1.06036D0/TBM**0.1561D0+19.3D-2/DEXP(0.47635D0*TBM)+1.0358
     $7D0/DEXP(1.52996D0*TBM)+1.76474D0/DEXP(3.89411D0*TBM)
      D(I,J)=2.66D-27*T**(1.5D0)*DSQRT(1/M(I)+1/M(J))/(P*IC(I,J)*DC(I,J
     $)**2*DSQRT(2))
 0010 CONTINUE
      END DO
      DO I=1,3
      DIFM(I)=0
      DO 20 J=1,3
      IF (J.EQ.I) GOTO 20
      DIFM(I)= DIFM(I)+Y(J)/D(I,J)
 0020 CONTINUE
      END DO
      DO I=1,3
      DIFM(I)=(1-Y(I))/DIFM(I)
      END DO
      Y(3)=Y(3)-Y(4)-Y(5)
      REWIND 1
      REWIND 2
      REWIND 3
      RETURN
      END
C***********************************************************************
C*                CALCULO DE LA DENSIDAD DE LA FASE GASEOSA            *
C***********************************************************************
      SUBROUTINE DENGAS (T,P,Y,DM,PMM)
      DOUBLE PRECISION T,P,Y(5),B(5,5),M(5),BM,PMM,Z,VM,DM
      CALL BVIR (T,B)
      BM=0
      DO I=1,5
      DO J=1,5
      BM=BM+Y(I)*Y(J)*B(I,J)
      END DO
      END DO
      OPEN(7,FILE='PESO-MOL.DAT')
      DO I=1,5
      READ(7,*)M(I)
      END DO
      REWIND 7
      PMM=0
      DO I=1,5
      PMM=PMM+Y(I)*M(I)
      END DO
      Z=1+BM*P/(T*83.14425525D0)
      VM=Z*83.14425525D0*T/P
      DM=PMM/VM*1D3
      REWIND 7
      RETURN
      END

C***********************************************************************
C*               CONDUCTIVIDAD TERMICA DE LA FASE GASESOSA             *
C***********************************************************************
      SUBROUTINE CTGAS (T,Y,CTM)
      DOUBLE PRECISION T,Y(5),M(5),TC(5),PC(5),GAMA(5),LAMDA(5,5),A(5,5)
     $,SUM,CTM,CTI(5)
      OPEN(1,FILE='TEM-CRI.DAT')
      OPEN(2,FILE='PRE-CRI.DAT')
      OPEN(3,FILE='PESO-MOL.DAT')
      DO I=1,5
      READ(1,*)TC(I)
      READ(2,*)PC(I)
      READ(3,*)M(I)
      END DO
      DO I=1,5
      GAMA(I)=210*(TC(I)*M(I)**3/PC(I)**4)**(1/6D0)
      END DO
      DO I=1,5
      DO J=1,5
      LAMDA(I,J)=GAMA(J)*(DEXP(0.0464D0*T/TC(I))-DEXP(-0.2412D0*T/TC(I))
     $)/(GAMA(I)*(DEXP(0.0464D0*T/TC(J))-DEXP(-0.2412D0*T/TC(J))))
      END DO
      END DO
      DO I=1,5
      DO J=1,5
      A(I,J)=(1+DSQRT(LAMDA(I,J))*(M(I)/M(J))**0.25)**2/DSQRT(8*(1+M(I)/
     $M(J)))
      END DO
      END DO
      CTI(1)=-7.215D-3+8.015D-5*T+5.477D-9*T**2-1.053D-11*T**3
      CTI(2)=7.341D-3-1.013D-5*T+1.801D-7*T**2-9.1D-11*T**3
      CTI(3)=3.919D-4+9.816D-5*T-5.067D-8*T**2+1.504D-11*T**3
      CTI(4)=-3.273D-4+9.966D-5*T-3.743D-8*T**2+9.732D-12*T**3
      CTI(5)=2.714D-3+5.54D-5*T-2.178D-8*T**2+5.528D-12*T**3
      DO I=1,5
      END DO
      CTM=0
      DO I=1,5
      SUM=0
      DO J=1,5
      SUM=SUM+Y(J)*A(I,J)
      END DO
      CTM=CTM+Y(I)*CTI(I)/SUM
      END DO
      REWIND 1
      REWIND 2
      REWIND 3
      RETURN
      END
C***********************************************************************
C*                 CAPACIDAD CALORFICA DE LA FASE GASEOSA             *
C***********************************************************************
      SUBROUTINE CPGAS (T,Y,CPM)
      DOUBLE PRECISION T,Y(5),CP(5),CPM
      CP(1)=19.8D0+7.344D-2*T-5.602D-5*T**2+1.715D-8*T**3
      CP(2)=32.24D0+1.924D-3*T+1.055D-5*T**2-3.596D-9*T**3
      CP(3)=31.15D0-1.357D-2*T+2.68D-5*T**2-1.168D-8*T**3
      CP(4)=28.11D0-3.68D-6*T+1.746D-5*T**2-1.065D-8*T**3
      CP(5)=28.8D0
      CPM=0
      DO I=1,5
      CPM=CPM+Y(I)*CP(I)
      END DO
      RETURN
      END
C***********************************************************************
C*         CALCULO DE LOS SEGUNDOS COEFICIENTES VIRIALES CRUZADOS      *
C***********************************************************************
      SUBROUTINE BVIR (T,B)
      DOUBLE PRECISION B0(5,5),B1(5,5),B(5,5),T,TC(5,5),PC(5,5),W(5,5),
     $PIB(5,5),ZC(5,5),VC(5,5)
      OPEN(1,FILE='TEM-CRI.DAT')
      OPEN(2,FILE='FAC-ACE.DAT')
      OPEN(3,FILE='PRE-CRI.DAT')
      OPEN(4,FILE='PAR-ITE.DAT')
      OPEN(5,FILE='VOL-CRI.DAT')
      OPEN(6,FILE='Z-CRI.DAT')
      DO I=1,5
      READ(1,*)TC(I,I)
      READ(2,*)W(I,I)
      READ(3,*)PC(I,I)
      READ(4,*)(PIB(I,J),J=1,5)
      READ(5,*)VC(I,I)
      READ(6,*)ZC(I,I)
      END DO
      DO I=1,5
      DO J=1,5
      TC(I,J)=(1-PIB(I,J))*DSQRT(TC(I,I)*TC(J,J))
      W(I,J)=(W(I,I)+W(J,J))/2
      ZC(I,J)=(ZC(I,I)+ZC(J,J))/2
      VC(I,J)=(VC(I,I)**(1/3D0)+VC(J,J)**(1/3D0))**3/8
      IF (I.EQ.J) GOTO 10
      PC(I,J)=ZC(I,J)*83.14425525D0*TC(I,J)/VC(I,J)
 0010 CONTINUE
      B0(I,J)=14.45D-2-3.3D-1*TC(I,J)/T-13.85D-2/(T/TC(I,J))**2-1.21D-2/
     $(T/TC(I,J))**3-6.07D-4/(T/TC(I,J))**8
      B1(I,J)=6.37D-2+3.31D-1/(T/TC(I,J))**2-4.23D-1/(T/TC(I,J))**3-8D-3
     $/(T/TC(I,J))**8
      B(I,J)=83.14425525D0*TC(I,J)*(B0(I,J)+W(I,J)*B1(I,J))/PC(I,J)
      END DO
      END DO
      REWIND 1
      REWIND 2
      REWIND 3
      REWIND 4
      REWIND 5
      REWIND 6
      RETURN
      END
C***********************************************************************
C*                       EQUILIBRIO FISICOQUIMICO                      *
C***********************************************************************
      SUBROUTINE EQUILI
      DOUBLE PRECISION X(4),T,C1,Y2,H,W1,X1,DML,XE(8),CE(8),CT,P2
      CHARACTER*5 COMND,CMP(8)
      DATA CMP/'MEA  ','CO2  ','MEA+ ','MEA- ','H2O  ','HCO3-','CO3= ','
     $OH-  '/
      COMND='CLS'
      CALL SYSTEM (COMND)
      WRITE(*,10)
  010 FORMAT(/,T33,'DATOS DE EQUILIBRIO',/)
  020 WRITE(*,*)'Temperatura de equilibrio T [K] = ? '
      READ(*,*,ERR=20)T
      IF (T.LE.273.15D0) GOTO 20
  030 WRITE(*,*)'Fraccin peso de MEA sin CO2 = ? '
      READ(*,*,ERR=30)W1
      IF (W1.LE.0.OR.W1.GE.1) GOTO 30
  040 WRITE(*,*)'Mol de CO2 / Mol de MEA  = ? '
      READ(*,*,ERR=40)Y2
      X1=W1*18.015D0/((1-W1)*61.084D0+W1*18.015D0)
      CALL DENLIQ (T,X1,DML)
      C1=W1*DML/61.084D0
      CALL EQUQUI (T,W1,Y2,DML,CE,CT)
      DO I=1,8
      XE(I)=CE(I)/CT
      END DO
      H=DEXP(22.2819D0-13.830611D3/T+6.913457D6/T**2-1.558951D9/T**3+0.1
     $20037D12/T**4)
      P2=(CE(2)*H*14.696D0/760)*101.325D0/14.696D0
      X(4)=XE(8)*CT/C1
      X(3)=XE(7)*CT/C1
      X(1)=2*XE(4)*CT/C1
      X(2)=XE(6)*CT/C1+X(3)
      WRITE(*,60)
  060 FORMAT(/,6X,'Fracciones mol en equilibrio',T44,'Conversiones en eq
     $uilibrio de MEA',/)
      DO I=1,8
      IF (I.LE.4) THEN
      WRITE(*,70)CMP(I),XE(I),I,X(I)
  070 FORMAT(5X,'XE ( ',A5,' ) = ',G15.7,T48,'X ( ',I1,' ) = ',G15.7)
      ELSE
      WRITE(*,80)CMP(I),XE(I)
  080 FORMAT(5X,'XE ( ',A5,' ) = ',G15.7)
      END IF
      END DO
      WRITE(*,90)CE(2),P2,H
  090 FORMAT(/,1X,'CO2 en equilibrio [gmol/l]            = ',G15.7,/,1X,
     $            'Presin parcial del CO2 [kPa]         = ',G15.7,/,1X,
     $            'Constante de Henry [mmHg l/gmol]      = ',G15.7,//)
      COMND='PAUSE'
      CALL SYSTEM (COMND)
      RETURN
      END
C***********************************************************************
C*                      FLUJO DE ALIMENTACIN DEL GAS                  *
C***********************************************************************
      SUBROUTINE CFG
      DOUBLE PRECISION T,P,DP,Y(5),DM,W,XAIR,CP,VM,WA,WM,PM,N1
      CHARACTER COMP(2)*3,COMND*5
      COMND='CLS'
      CALL SYSTEM (COMND)
      DATA COMP/'CO2','H2O'/
      WRITE(*,10)
  010 FORMAT(///,T27,'FLUJO DE ALIMENTACIN DEL GAS',///)
  020 WRITE(*,*)'Temperatura de alimentacin del gas [K] = ? '
      READ(*,*,ERR=20) T
      IF (T.LE.273.15D0) GOTO 20
  030 WRITE(*,*)'Presin manomtrica del gas [Kg/cm] = ? '
      READ(*,*,ERR=30)P
      IF (P.LE.0.OR.P.GT.4) GOTO 30
  040 WRITE(*,*)'Cada de presin en la placa de orificio [cm H2O] = ? '
      READ(*,*,ERR=40)DP
      IF (DP.LE.0) GOTO 40
      DO I=1,2
  050 WRITE(*,60)COMP(I)
  060 FORMAT(1X,'Fraccin mol del ',A3,' = ? ')
      READ(*,*,ERR=50)Y(I)
      IF (Y(I).LT.0.OR.Y(I).GT.1) GOTO 50
      END DO
      XAIR=1-Y(1)-Y(2)
      Y(3)=0.7806D0*XAIR
      Y(4)=0.2101D0*XAIR
      Y(5)=0.0093D0*XAIR
      P=P*1.01325D0/1.0333D0+0.78D0
      CALL DENGAS (T,P,Y,DM,PM)
      CALL CPGAS (T,Y,CP)
      CALL VISGAS (T,P,Y,VM)
      CALL FLUGAS(Y,P,DP,DM,CP,VM,W,WA,WM)
      N1=WM*Y(1)
      WRITE(*,70)W,WA,WM,PM,N1
  070 FORMAT(/,1X,'Flujo msico [Kg/s]              = ',G15.7,
     $       /,1X,'Masa velocidad [Kg/s m]         = ',G15.7,
     $       /,1X,'Masa velocidad molar [Kmol/s m] = ',G15.7,
     $       /,1X,'Peso molecular de la mezcla      = ',G15.7,
     $       /,1X,'Flujo del CO2 [kmol/s m]        = ',G15.7,///)
      COMND='PAUSE'
      CALL SYSTEM (COMND)
      RETURN
      END
C***********************************************************************
C*                   FLUJO DE ALIMENTACIN DEL LQUIDO                 *
C***********************************************************************
      SUBROUTINE CFL
      DOUBLE PRECISION T,W1,X1,LEC,W,DM,WA,WAM,PM,N1
      CHARACTER*5 COMND
      COMND='CLS'
      CALL SYSTEM (COMND)
      WRITE(*,10)
  010 FORMAT(////,T25,'FLUJO DE ALIMENTACIN DEL LQUIDO',///)
  020 WRITE(*,*)'Temperatura de alimentacin del lquido T [K] = ? '
      READ(*,*,ERR=20)T
  030 WRITE(*,*)'Fraccin peso de la MEA sin CO2 = ? '
      READ(*,*,ERR=30)W1
  040 WRITE(*,*)'Lectuta del rotmetro = ? '
      READ(*,*,ERR=40)LEC
      X1=W1*18.015D0/((1-W1)*61.084D0+W1*18.015D0)
      PM=X1*61.084D0+(1-X1)*18.015D0
      CALL DENLIQ (T,X1,DM)
      W=(4.9509125D0*LEC-2.816684375D0-2.567734209D0*W1)*DM/1D6
      WA=W/(3.141592654D0*7.8D-2**2/4)
      WAM=WA/PM
      N1=WAM*X1
      WRITE(*,50)W,WA,WAM,N1
  050 FORMAT(//,1X,'Flujo msico [Kg/s]              = ',G15.7,
     $        /,1X,'Masa velocidad [Kg/s m]         = ',G15.7,
     $        /,1X,'Masa velocidad molar [Kmol/s m] = ',G15.7,
     $        /,1X,'Flujo de la MEA [kmol/s m]        = ',G15.7,///)
      COMND='PAUSE'
      CALL SYSTEM (COMND)
      RETURN
      END
C***********************************************************************
C*                       FLUJO DEL LQUIDO MNIMO                      *
C***********************************************************************
      SUBROUTINE CFLM
      DOUBLE PRECISION X(4),T,C1,Y2,C2,H,W1,X1,DML,P2,Y1S,Y1C,Y2A,Y2B,Y1
     $E,FG,Y2E,Y2S,Z,Z1,FG1,X0,X2,FL,FL1
      CHARACTER*5 COMND
      COMND='CLS'
      CALL SYSTEM (COMND)
      WRITE(*,10)
  010 FORMAT(///,T30,'FLUJO MMINO DE LQUIDO',///)
  020 WRITE(*,*)'Temperatura del lquido [K] = ? '
      READ(*,*,ERR=20)T
      IF (T.LE.273.15D0) GOTO 20
  030 WRITE(*,*)'Fracccin peso de la MEA sin CO2 = ? '
      READ(*,*,ERR=30)W1
      IF (W1.LE.0.OR.W1.GE.1) GOTO 30
  040 WRITE(*,*)'Frac. mol CO2 en el gas de entrada a la columna = ? '
      READ(*,*,ERR=40)Y1E
      IF (Y1E.LE.0.OR.Y1E.GE.1) GOTO 40
  050 WRITE(*,*)'Frac. mol CO2 en el gas de salida de la columna = ? '
      READ(*,*,ERR=50)Y1S
      IF (Y1S.LE.0.OR.Y1E.GE.1) GOTO 50
  060 WRITE(*,*)'Flujo del gas de alimentacin [kg/s] = ? '
      READ(*,*,ERR=60)FG
      IF (FG.LE.0) GOTO 60
      X1=W1*18.015D0/((1-W1)*61.084D0+W1*18.015D0)
      CALL DENLIQ (T,X1,DML)
      C1=W1*DML/61.084D0
      Y2=0.5
      Y2A=0
      Y2B=1
  070 CALL NEWMULT (X,T,C1,Y2)
      C2=C1*(Y2-.5D0*X(1)-X(2))
      H=DEXP(22.2819D0-13.830611D3/T+6.913457D6/T**2-1.558951D9/T**3+0.1
     $20037D12/T**4)
      P2=(C2*H*14.696D0/760)*101.325D0/14.696D0
      Y1C=P2/78
      IF (ABS(Y1C-Y1E)/Y1E.LT.0.001) GOTO 80
      IF (Y1C.GT.Y1E) THEN
      Y2B=Y2
      ELSE
      Y2A=Y2
      END IF
      Y2=(Y2A+Y2B)/2
      GOTO 70
  080 Y2E=Y1E/(1-Y1E)
      Z=44.01D0*Y2E/28.96D0
      Z1=Z/(1+Z)
      FG1=FG*(1-Z1)/28.96D0
      Y2S=Y1S/(1-Y1S)
      X0=18.015D0*W1/(61.084*(1-W1))
      X2=Y2*X0/(1+X0)
      FL1=FG1*(Y2E-Y2S)/X2
      FL=FL1*(18.015D0+61.084*X0)/(1+X0)
      WRITE(*,90)P2,H,Y2,FL
  090 FORMAT(/,1X,'Presin parcial del CO2 [kPa]         = ',G15.7,/,1X,
     $            'Constante de Henry [mmHg l/gmol]      = ',G15.7,/,1X,
     $            'Mol CO2 inicial/mol MEA inicial       = ',G15.7,/,1X,
     $            'Flujo mmino del lquido [kg/s]       = ',G15.7,///)
      COMND='PAUSE'
      CALL SYSTEM (COMND)
      RETURN
      END
C***********************************************************************
C*          CLCULO DE LA CADA DE PRESIN EN COLUMNAS EMPACADAS       *
C***********************************************************************
      SUBROUTINE FACTOR
      DOUBLE PRECISION A(8),B(8),Y(8),P(8),PA,DP,YG(5),XAIR,W1,X1,WL,LEC
     $,WG,WG1,DG,DL,X,P1,P2,Y1,Y2,PE,YE,H,FPH,FPD,FP,TL,TG,PMG,VG,CG
      DATA A/0.25,0.165,0.125,0.073,0.034,0.017,0.007,0.0013/
      DATA B/1.3,1.1,1.0,0.9,0.77,0.6,0.42,0.235/
      DATA P/0,1.5,1,0.5,0.2,0.1,0.05,0.01/
      CHARACTER COMP(2)*3,COMND*5
      COMND='CLS'
      CALL SYSTEM (COMND)
      DATA COMP/'CO2','H2O'/
      WRITE(*,10)
  010 FORMAT(///,T33,'FACTOR DE EMPAQUE',///)
  020 WRITE(*,*)'Temperatura de alimentacin del lquido [K] = ? '
      READ(*,*,ERR=20)TL
  030 WRITE(*,*)'Tempetarura de alimentacin del gas [K] =  ? '
      READ(*,*,ERR=30)TG
  040 WRITE(*,*)'Presin manomtrica del gas [Kg/cm] = ? '
      READ(*,*,ERR=40)PA
  050 WRITE(*,*)'Cada de presin en la placa de orificio [cm H2O] = ? '
      READ(*,*,ERR=50)DP
  060 WRITE(*,*)'Cada de presin en la columna empacada [cm H2O] = ? '
      READ(*,*,ERR=60)PE
  070 WRITE(*,*)'Lectura del rotmetro = ? '
      READ(*,*,ERR=70)LEC
      DO I=1,2
  080 WRITE(*,90)COMP(I)
  090 FORMAT(1X,'Fraccin mol del ',A3,' = ? ')
      READ(*,*,ERR=80)YG(I)
      END DO
      WRITE(*,*)'Fraccin peso de la MEA sin CO2 = ? '
      READ(*,*)W1
      X1=W1*18.015D0/((1-W1)*61.084D0+W1*18.015D0)
      XAIR=1-YG(1)-YG(2)
      YG(3)=0.7806D0*XAIR
      YG(4)=0.2101D0*XAIR
      YG(5)=0.0093D0*XAIR
      PA=PA*1.01325D0/1.0333D0+0.78D0
      CALL DENGAS (TG,PA,YG,DG,PMG)
      CALL VISGAS (TG,PA,YG,VG)
      CALL CPGAS (TG,YG,CG)
      CALL DENLIQ (TL,X1,DL)
      CALL FLUGAS  (YG,PA,DP,DG,CG,VG,WG,WG1,WG2)
      CALL FLULIQ  (W1,X1,LEC,DL,WL,WL1,WL2)
      PE=PE*30.48D0/(2.54D0*145)
      X=WL*DSQRT(DG/DL)/WG
      DO I=1,8
      Y(I)=A(I)/(1+(B(I)*X)**0.65D0)**(1/0.325D0)
      END DO
      IF (PE.GT.1.5) THEN
      YE=Y(1)
      GOTO 110
      END IF
      DO I=2,7
      IF (PE.LT.P(I).AND.PE.GT.P(I+1)) THEN
      P1=P(I)
      P2=P(I+1)
      Y1=Y(I)
      Y2=Y(I+1)
      END IF
      END DO
      YE=(Y1+Y2)/2
      H=1D-7
      DO I=1,15
      FP=PE-P1*(P2/P1)**(LOG10(Y1/YE)/LOG10(Y1/Y2))
      IF (ABS(FP).LT.0.001) GOTO 110
      YE=H+YE
      FPH=PE-P1*(P2/P1)**(LOG10(Y1/YE)/LOG10(Y1/Y2))
      FPD=(FPH-FP)/H
      YE=YE-H
      YE=YE-FP/FPD
      END DO
      WRITE(*,100)
  100 FORMAT(//,1X,'No convergio despus de  de 15 iteraciones')
  110 F=YE*9.81D0*0.3048D0*DG*DL/WG1**2
      WRITE(*,120)F
  120 FORMAT(/,2X,'Factor de empaque en [1/ft] = ',G15.7,///)
      COMND='PAUSE'
      CALL SYSTEM (COMND)
      RETURN
      END
C***********************************************************************
C*               CALCULO DE LA DENSIDAD DE LA FASE LIQUIDA             *
C***********************************************************************
      SUBROUTINE CDL
      DOUBLE PRECISION T,W1,X1,D1,D2,VE,VM,DM
      CHARACTER*5 COMND
      COMND='CLS'
      CALL SYSTEM (COMND)
      WRITE(*,10)
  010 FORMAT(///,T28,'DENSIDAD DE LA FASE LIQUIDA',///)
  020 WRITE(*,*)'Temperatura del lquido [K] = ? '
      READ(*,*,ERR=20)T
      IF (T.LE.273.15) GOTO 20
  030 WRITE(*,*)'Fraccin peso de la MEA = ? '
      READ(*,*,ERR=30)W1
      IF (W1.LT.0.OR.W1.GT.1) GOTO 30
      D1=1.283609904D0-0.9829456948D-3*T+2.576495034D-7*T**2
      D2=0.8108397753D0+1.544995123D-3*T-3.084391807D-6*T**2
      X1=W1*18.015D0/((1-W1)*61.084D0+W1*18.015D0)
      VE=(X1-X1**2)*(20.963D0-0.18249D0*T+3.29582D-4*T**2+(2*X1-1)*(23.0
     $844D0-0.197554D0*T+3.70423D-4*T**2))
      VM=VE+X1*61.084D0/D1+(1-X1)*18.015D0/D2
      DM=(X1*61.084D0+(1-X1)*18.015D0)/VM
      D1=1000*D1
      D2=1000*D2
      DM=1000*DM
      WRITE(*,40)X1,D1,D2,DM
  040 FORMAT(//,1X,'Fraccin mol de MEA                  = ',G15.7,
     $        /,1X,'Densidad de la MEA [kg/m]           = ',G15.7,
     $        /,1X,'Densidad del agua [kg/m]            = ',G15.7,
     $        /,1X,'Densidad de la mezcla [kg/m]        = ',G15.7,////)
      COMND='PAUSE'
      CALL SYSTEM (COMND)
      RETURN
      END
